%global _hardened_build 1

%global _for_fedora_koji_builds 0

# uncomment and add '%' to use the prereltag for pre-releases
# %%global prereltag qa3

##-----------------------------------------------------------------------------
## All argument definitions should be placed here and keep them sorted
##

# if you wish to compile an rpm with debugging...
# rpmbuild -ta glusterfs-3.8.4.tar.gz --with debug
%{?_with_debug:%global _with_debug --enable-debug}

# if you wish to compile an rpm with cmocka unit testing...
# rpmbuild -ta glusterfs-3.8.4.tar.gz --with cmocka
%{?_with_cmocka:%global _with_cmocka --enable-cmocka}

# if you wish to compile an rpm without rdma support, compile like this...
# rpmbuild -ta glusterfs-3.8.4.tar.gz --without rdma
%{?_without_rdma:%global _without_rdma --disable-ibverbs}

# No RDMA Support on s390(x)
%ifarch s390 s390x
%global _without_rdma --disable-ibverbs
%endif

# if you wish to compile an rpm without epoll...
# rpmbuild -ta glusterfs-3.8.4.tar.gz --without epoll
%{?_without_epoll:%global _without_epoll --disable-epoll}

# if you wish to compile an rpm without fusermount...
# rpmbuild -ta glusterfs-3.8.4.tar.gz --without fusermount
%{?_without_fusermount:%global _without_fusermount --disable-fusermount}

# if you wish to compile an rpm without geo-replication support, compile like this...
# rpmbuild -ta glusterfs-3.8.4.tar.gz --without georeplication
%{?_without_georeplication:%global _without_georeplication --disable-georeplication}

# Disable geo-replication on EL5, as its default Python is too old
%if ( 0%{?rhel} && 0%{?rhel} < 6 )
%global _without_georeplication --disable-georeplication
%endif

# if you wish to compile an rpm without the OCF resource agents...
# rpmbuild -ta glusterfs-3.8.4.tar.gz --without ocf
%{?_without_ocf:%global _without_ocf --without-ocf}

# if you wish to build rpms without syslog logging, compile like this
# rpmbuild -ta glusterfs-3.8.4.tar.gz --without syslog
%{?_without_syslog:%global _without_syslog --disable-syslog}

# disable syslog forcefully as rhel <= 6 doesn't have rsyslog or rsyslog-mmcount
# Fedora deprecated syslog, see
#  https://fedoraproject.org/wiki/Changes/NoDefaultSyslog
# (And what about RHEL7?)
%if ( 0%{?fedora} && 0%{?fedora} >= 20 ) || ( 0%{?rhel} && 0%{?rhel} <= 6 )
%global _without_syslog --disable-syslog
%endif

# if you wish to compile an rpm without the BD map support...
# rpmbuild -ta glusterfs-3.8.4.tar.gz --without bd
%{?_without_bd:%global _without_bd --disable-bd-xlator}

%if ( 0%{?rhel} && 0%{?rhel} < 6 || 0%{?sles_version} )
%global _without_bd --disable-bd-xlator
%endif

# Disable data-tiering on EL5, sqlite is too old
%if ( 0%{?rhel} && 0%{?rhel} < 6 )
%global _without_tiering --disable-tiering
%endif

# if you wish not to build server rpms, compile like this.
# rpmbuild -ta glusterfs-3.8.4.tar.gz --without server

%global _build_server 1
%if "%{?_without_server}"
%global _build_server 0
%endif

%if ( "%{?dist}" == ".el6rhs" ) || ( "%{?dist}" == ".el7rhs" ) || ( "%{?dist}" == ".el7rhgs" )
%global _build_server 1
%else
%global _build_server 0
%global _without_georeplication --disable-georeplication
%endif

%global _without_extra_xlators 1
%global _without_regression_tests 1

%global _build_server 1
##-----------------------------------------------------------------------------
## All %%global definitions should be placed here and keep them sorted
##

%if ( 0%{?fedora} && 0%{?fedora} > 16 ) || ( 0%{?rhel} && 0%{?rhel} > 6 )
%global _with_systemd true
%endif

%if ( 0%{?fedora} ) || ( 0%{?rhel} && 0%{?rhel} >= 7 )
%global _with_firewalld --enable-firewalld
%endif

%if 0%{?_tmpfilesdir:1}
%global _with_tmpfilesdir --with-tmpfilesdir=%{_tmpfilesdir}
%else
%global _with_tmpfilesdir --without-tmpfilesdir
%endif

# Eventing
%if 0%{?_build_server}
%if ( 0%{?rhel} && 0%{?rhel} < 6 )
%global _without_events --disable-events
%endif
%endif

# From https://fedoraproject.org/wiki/Packaging:Python#Macros
%if ( 0%{?rhel} && 0%{?rhel} <= 5 )
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
%endif

%if ( 0%{?_with_systemd:1} )
%global _init_enable()  /bin/systemctl enable %1.service ;
%global _init_disable() /bin/systemctl disable %1.service ;
%global _init_restart() /bin/systemctl try-restart %1.service ;
%global _init_start()   /bin/systemctl start %1.service ;
%global _init_stop()    /bin/systemctl stop %1.service ;
%global _init_install() install -D -p -m 0644 %1 %{buildroot}%{_unitdir}/%2.service ;
# can't seem to make a generic macro that works
%global _init_glusterd   %{_unitdir}/glusterd.service
%global _init_glusterfsd %{_unitdir}/glusterfsd.service
%global _init_glustereventsd %{_unitdir}/glustereventsd.service
%else
%global _init_enable()  /sbin/chkconfig --add %1 ;
%global _init_disable() /sbin/chkconfig --del %1 ;
%global _init_restart() /sbin/service %1 condrestart &>/dev/null ;
%global _init_start()   /sbin/service %1 start &>/dev/null ;
%global _init_stop()    /sbin/service %1 stop &>/dev/null ;
%global _init_install() install -D -p -m 0755 %1 %{buildroot}%{_sysconfdir}/init.d/%2 ;
# can't seem to make a generic macro that works
%global _init_glusterd   %{_sysconfdir}/init.d/glusterd
%global _init_glusterfsd %{_sysconfdir}/init.d/glusterfsd
%global _init_glustereventsd %{_sysconfdir}/init.d/glustereventsd
%endif

%if ( 0%{_for_fedora_koji_builds} )
%if ( 0%{?_with_systemd:1} )
%global glusterfsd_service glusterfsd.service
%else
%global glusterfsd_service glusterfsd.init
%endif
%endif

%{!?_pkgdocdir: %global _pkgdocdir %{_docdir}/%{name}-%{version}}

%if ( 0%{?rhel} && 0%{?rhel} < 6 )
# _sharedstatedir is not provided by RHEL5
%global _sharedstatedir /var/lib
%endif

# We do not want to generate useless provides and requires for xlator
# .so files to be set for glusterfs packages.
# Filter all generated:
#
# TODO: RHEL5 does not have a convenient solution
%if ( 0%{?rhel} == 6 )
# filter_setup exists in RHEL6 only
%filter_provides_in %{_libdir}/glusterfs/%{version}/
%global __filter_from_req %{?__filter_from_req} | grep -v -P '^(?!lib).*\.so.*$'
%filter_setup
%else
# modern rpm and current Fedora do not generate requires when the
# provides are filtered
%global __provides_exclude_from ^%{_libdir}/glusterfs/%{version}/.*$
%endif


##-----------------------------------------------------------------------------
## All package definitions should be placed here in alphabetical order
##
Summary:          Distributed File System
%if ( 0%{_for_fedora_koji_builds} )
Name:             glusterfs
Version:          3.8.0
Release:          0.1%{?prereltag:.%{prereltag}}%{?dist}
Vendor:           Fedora Project
%else
Name:             glusterfs
Version:          3.8.4
Release:          18.4%{?dist}
ExclusiveArch:    x86_64 aarch64
%endif
License:          GPLv2 or LGPLv3+
Group:            System Environment/Base
URL:              http://www.gluster.org/docs/index.php/GlusterFS
%if ( 0%{_for_fedora_koji_builds} )
Source0:          http://bits.gluster.org/pub/gluster/glusterfs/src/glusterfs-%{version}%{?prereltag}.tar.gz
Source1:          glusterd.sysconfig
Source2:          glusterfsd.sysconfig
Source6:          rhel5-load-fuse-modules
Source7:          glusterfsd.service
Source8:          glusterfsd.init
%else
Source0:          glusterfs-3.8.4.tar.gz
%endif

BuildRoot:        %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

%if ( 0%{?rhel} && 0%{?rhel} <= 5 )
BuildRequires:    python-simplejson
%endif
%if ( 0%{?_with_systemd:1} )
BuildRequires:    systemd
%endif

Requires:         %{name}-libs%{?_isa} = %{version}-%{release}
%if ( 0%{?_with_systemd:1} )
%{?systemd_requires}
%endif
BuildRequires:    git
BuildRequires:    bison flex
BuildRequires:    gcc make libtool
BuildRequires:    ncurses-devel readline-devel
BuildRequires:    libxml2-devel openssl-devel
BuildRequires:    libaio-devel libacl-devel
BuildRequires:    python-devel
BuildRequires:    python-ctypes
BuildRequires:    userspace-rcu-devel >= 0.7
%if ( 0%{?rhel} && 0%{?rhel} <= 6 )
BuildRequires:    automake
%endif
%if ( 0%{?rhel} && 0%{?rhel} <= 5 )
BuildRequires:    e2fsprogs-devel
%else
BuildRequires:    libuuid-devel
%endif
%if ( 0%{?_with_cmocka:1} )
BuildRequires:    libcmocka-devel >= 1.0.1
%endif
%if ( 0%{!?_without_tiering:1} )
BuildRequires:    sqlite-devel
%endif
%if ( 0%{!?_without_bd:1} )
BuildRequires:    lvm2-devel
%endif
%if ( 0%{!?_without_georeplication:1} )
BuildRequires:    libattr-devel
%endif
BuildRequires:    libattr-devel

%if (0%{?_with_firewalld:1})
BuildRequires:    firewalld
%endif

Obsoletes:        hekafs
Obsoletes:        %{name}-common < %{version}-%{release}
Obsoletes:        %{name}-core < %{version}-%{release}
Obsoletes:        %{name}-ufo
Provides:         %{name}-common = %{version}-%{release}
Provides:         %{name}-core = %{version}-%{release}

# Patch0001: 0001-Update-rfc.sh-to-rhgs-3.2.0.patch
Patch0002: 0002-glusterd-fix-op-versions-for-RHS-backwards-compatabi.patch
Patch0003: 0003-tier-ctr-sql-Dafault-values-for-sql-cache-and-wal-si.patch
Patch0004: 0004-rpc-set-bind-insecure-to-off-by-default.patch
Patch0005: 0005-glusterd-spec-fixing-autogen-issue.patch
Patch0006: 0006-libglusterfs-glusterd-Fix-compilation-errors.patch
Patch0007: 0007-build-remove-ghost-directory-entries.patch
Patch0008: 0008-build-add-RHGS-specific-changes.patch
Patch0009: 0009-secalert-remove-setuid-bit-for-fusermount-glusterfs.patch
Patch0010: 0010-build-packaging-corrections-for-RHEL-5.patch
Patch0011: 0011-build-introduce-security-hardening-flags-in-gluster.patch
Patch0012: 0012-spec-fix-add-pre-transaction-scripts-for-geo-rep-and.patch
Patch0013: 0013-rpm-glusterfs-devel-for-client-builds-should-not-dep.patch
Patch0014: 0014-build-add-pretrans-check.patch
Patch0015: 0015-build-exclude-libgfdb.pc-conditionally.patch
Patch0016: 0016-build-exclude-glusterfs.xml-on-rhel-7-client-build.patch
Patch0017: 0017-glusterd-fix-info-file-checksum-mismatch-during-upgr.patch
Patch0018: 0018-build-spec-file-conflict-resolution.patch
Patch0019: 0019-build-dependency-error-during-upgrade.patch
Patch0020: 0020-Revert-gfapi-upcall-Use-GF_CALLOC-while-allocating-v.patch
Patch0021: 0021-logging-Change-log-file-name-for-glusterd.patch
Patch0022: 0022-glusterd-search-for-free-port-from-base_port.patch
Patch0023: 0023-glusterd-clean-up-old-port-and-allocate-new-one-on-e.patch
Patch0024: 0024-glusterd-Improve-mountbroker-logs.patch
Patch0025: 0025-glusterd-Fix-msgid-in-mountbroker-logs.patch
Patch0026: 0026-mgmt-glusterd-Enable-client-io-threads-by-default.patch
Patch0027: 0027-feature-bitrot-Ondemand-scrub-option-for-bitrot.patch
Patch0028: 0028-glusterd-cli-cli-to-get-local-state-representation-f.patch
Patch0029: 0029-eventsapi-Gluster-Eventing-Feature-implementation.patch
Patch0030: 0030-eventsapi-Fix-make-install-issue-second-time.patch
Patch0031: 0031-eventsapi-Volume-Set-and-Reset-Events.patch
Patch0032: 0032-eventsapi-Auto-generate-header-files-during-make.patch
Patch0033: 0033-eventsapi-Geo-replication-User-driven-events.patch
Patch0034: 0034-eventsapi-Python-library-for-gf_event.patch
Patch0035: 0035-events-move-conditional-macro-check-USE_EVENTS-insid.patch
Patch0036: 0036-eventsapi-Fix-disable-events-issue.patch
Patch0037: 0037-extras-kill-processes-gracefully.patch
Patch0038: 0038-extras-kill-gsyncd-before-glusterfsd.patch
Patch0039: 0039-build-fix-eventtypes.h-generation.patch
Patch0040: 0040-packaging-eventsapi-Make-Python-site-packages-variab.patch
Patch0041: 0041-eventsapi-Add-support-for-Client-side-Events.patch
Patch0042: 0042-eventsapi-Fix-Volume-Stop-and-delete-prompt-issue.patch
Patch0043: 0043-features-ganesha-remove-ganesha-xlator-from-client-g.patch
Patch0044: 0044-eventsapi-Add-Init-scripts-for-different-distributio.patch
Patch0045: 0045-eventsapi-Add-conditional-import-for-requests-librar.patch
Patch0046: 0046-eventsapi-packaging-Fix-conflict-during-rpm-install.patch
Patch0047: 0047-eventsapi-Bitrot-events.patch
Patch0048: 0048-glusterd-Add-async-events.patch
Patch0049: 0049-glusterd-add-async-events-part-2.patch
Patch0050: 0050-quota-cli-add-user-driven-quota-events.patch
Patch0051: 0051-quota-add-quota-events.patch
Patch0052: 0052-eventsapi-declare-all-the-identified-events-at-one-g.patch
Patch0053: 0053-protocol-server-generate-events.patch
Patch0054: 0054-extras-cliutils-Utils-for-creating-CLI-tools-for-Glu.patch
Patch0055: 0055-glusterd-ganesha-Move-ganesha-ha.conf-and-ganesha.co.patch
Patch0056: 0056-ganesha-scripts-remove-HA_VOL_SERVER-from-the-code.patch
Patch0057: 0057-afr-add-replication-events.patch
Patch0058: 0058-glusterd-Introduce-reset-brick.patch
Patch0059: 0059-Revert-glusterd-ganesha-copy-ganesha-export-configur.patch
Patch0060: 0060-ganesha-scripts-Modifying-ganesha-ha.sh-for-share-st.patch
Patch0061: 0061-glusterd-ganesha-create-export-configuration-file-in.patch
Patch0062: 0062-event-fix-gf_event-messages-for-replace-reset-brick-.patch
Patch0063: 0063-cluster-ec-Add-events-for-EC-translator.patch
Patch0064: 0064-storage-posix-Integrate-important-events-with-gf_eve.patch
Patch0065: 0065-cluster-tier-add-tiering-events.patch
Patch0066: 0066-xlators-ganesha-Remove-the-ganesha-xlator-code-entir.patch
Patch0067: 0067-snapshot-eventsapi-Integrate-snapshot-events-with-ev.patch
Patch0068: 0068-ganesha-glusterd-Correct-the-path-for-ganesha-conf-d.patch
Patch0069: 0069-events-dht-dht-cli-events.patch
Patch0070: 0070-dht-events-Added-rebalance-events.patch
Patch0071: 0071-geo-rep-Use-configured-log_level-for-libgfchangelog-.patch
Patch0072: 0072-cluster-dht-heal-root-permission-post-add-brick.patch
Patch0073: 0073-geo-rep-add-geo-rep-events-for-server-side-changes.patch
Patch0074: 0074-cluster-dht-Skip-layout-overlap-maximization-on-weig.patch
Patch0075: 0075-geo-rep-Simplify-Non-root-user-mountbroker-Setup.patch
Patch0076: 0076-protocol-client-fix-coding-style-violations.patch
# Patch0077: 0077-infra-remove-anti-typedef-check.patch
Patch0078: 0078-compound-fops-Some-fixes-to-compound-fops-framework.patch
Patch0079: 0079-afr-Consume-compound-fops-in-afr-transaction.patch
Patch0080: 0080-geo-rep-Defunct-tar-process-after-sync.patch
Patch0081: 0081-geo-rep-Fix-Geo-rep-status-if-monitor.pid-file-not-e.patch
Patch0082: 0082-geo-rep-Fix-logging-sync-failures.patch
Patch0083: 0083-eventsapi-Fix-eventtypes.h-header-generation-with-Py.patch
Patch0084: 0084-build-linux-oom.h-fix-for-RHEL-5.patch
Patch0085: 0085-syscall-remove-preadv-and-pwritev-sys-wrappers.patch
Patch0086: 0086-build-ignore-sbindir-conf.py-for-RHEL-5.patch
Patch0087: 0087-socket-pollerr-event-shouldn-t-trigger-socket_connne.patch
Patch0088: 0088-afr-Modifications-to-afr-events.patch
Patch0089: 0089-build-add-systemd-dependency.patch
Patch0090: 0090-glusterfsd-explicitly-turn-on-encryption-for-volfile.patch
Patch0091: 0091-glusterd-fix-return-val-in-glusterd_op_volume_dict_u.patch
Patch0092: 0092-afr-Ignore-gluster-internal-virtual-xattrs-in-metada.patch
Patch0093: 0093-dht-udpate-stbuf-from-servers-those-have-layout.patch
Patch0094: 0094-eventsapi-geo-rep-Geo-rep-will-not-work-without-even.patch
Patch0095: 0095-gfapi-Fix-few-fd-ref-leaks.patch
Patch0096: 0096-socket-log-the-client-identifier-in-ssl-connect.patch
Patch0097: 0097-performance-open-behind-Pass-O_DIRECT-flags-for-anon.patch
Patch0098: 0098-cluster-ec-set-unset-dirty-flag-for-data-metadata-up.patch
Patch0099: 0099-cluster-ec-Implement-heal-info-with-lock.patch
Patch0100: 0100-cluster-ec-Use-locks-for-opendir.patch
Patch0101: 0101-system-posix-acl-Unwind-with-NULL-xdata-on-error.patch
Patch0102: 0102-afr-Take-full-locks-in-arbiter-only-for-data-transac.patch
Patch0103: 0103-rpc-socket.c-Modify-gf_log-message-in-socket_poller-.patch
Patch0104: 0104-build-randomize-temp-file-names-in-pretrans-scriptle.patch
Patch0105: 0105-cluster-afr-Prevent-dict_set-on-NULL-dict.patch
Patch0106: 0106-glusterd-enable-default-configurations-post-upgrade-.patch
Patch0107: 0107-cluster-ec-Do-multi-threaded-self-heal.patch
Patch0108: 0108-geo-rep-eventsapi-Additional-Events.patch
Patch0109: 0109-storage-posix-Fix-race-in-posix_pstat.patch
Patch0110: 0110-glusterd-set-the-brickinfo-port-before-spawning-the-.patch
Patch0111: 0111-upcall-Add-support-to-invalidate-xattrs.patch
Patch0112: 0112-upcall-pass-dict-with-xattrs-on-xattr-invalidation.patch
Patch0113: 0113-md-cache-Cache-gluster-samba-metadata.patch
Patch0114: 0114-upcall-Invalidation-for-xattr-should-also-carry-a-va.patch
Patch0115: 0115-md-cache-Enable-caching-of-stat-fetched-from-readdir.patch
Patch0116: 0116-md-cache-Add-cache-invalidation-support-for-metadata.patch
Patch0117: 0117-md-cache-fix-indention-to-silence-Coverity.patch
Patch0118: 0118-md-cache-upcall-In-case-of-mode-bit-change-invalidat.patch
Patch0119: 0119-md-cache-Add-logging-to-increase-debuggability.patch
Patch0120: 0120-md-cache-Add-cache-hit-and-miss-counters.patch
Patch0121: 0121-md-cache-Do-not-use-features.cache-invalidation-for-.patch
Patch0122: 0122-md-cache-Fix-wrong-cache-time-update-for-xattrs.patch
Patch0123: 0123-dht-define-GF_IPC_TARGET_UPCALL.patch
Patch0124: 0124-dht-Implement-ipc-fop.patch
Patch0125: 0125-io-stats-Add-ipc-fop-for-display-in-the-profile-info.patch
Patch0126: 0126-upcall-Add-permission-change-flag-to-iatt-flag.patch
Patch0127: 0127-md-cache-Register-the-list-of-xattrs-with-cache-inva.patch
Patch0128: 0128-dht-md-cache-upcall-Add-invalidation-of-IATT-when-th.patch
Patch0129: 0129-md-cache-Process-all-the-cache-invalidation-flags.patch
Patch0130: 0130-upcall-Mark-the-clients-as-accessed-on-readdirp-entr.patch
Patch0131: 0131-io-stats-Add-stats-for-upcall-notifications.patch
Patch0132: 0132-ec-Implement-ipc-fop.patch
Patch0133: 0133-afr-Implement-IPC-fop.patch
Patch0134: 0134-md-cache-afr-Reduce-the-window-of-stale-read.patch
Patch0135: 0135-cli-glusterd-Address-issues-in-get-state-cli-output.patch
Patch0136: 0136-rpc-socket-Close-pipe-on-disconnection.patch
Patch0137: 0137-ganesha-scripts-modify-start-hook-script-for-shared-.patch
Patch0138: 0138-performance-io-threads-Exit-all-threads-on-PARENT_DO.patch
Patch0139: 0139-glusterd-conditionally-pass-uuid-for-EVENT_PEER_CONN.patch
Patch0140: 0140-eventsapi-packaging-Fix-wrong-usage-of-post.patch
Patch0141: 0141-compound-fops-Fix-file-corruption-issue.patch
Patch0142: 0142-rpc-Fix-the-race-between-notification-and-reconnecti.patch
Patch0143: 0143-cluster-dht-Incorrect-volname-in-rebalance-events.patch
Patch0144: 0144-events-add-TIER_START-and-TIER_START_FORCE-events.patch
Patch0145: 0145-tools-glusterfind-kill-remote-processes-and-separate.patch
Patch0146: 0146-afr-ec-Heal-device-files-with-correct-major-minor-nu.patch
Patch0147: 0147-rpc-socket.c-Modify-socket_poller-code-in-case-of-EN.patch
Patch0148: 0148-md-cache-Invalidate-cache-entry-for-open-with-O_TRUN.patch
Patch0149: 0149-glusterd-shared-storage-Check-for-hook-script-at-sta.patch
Patch0150: 0150-gfapi-async-fops-should-unref-in-callbacks.patch
Patch0151: 0151-CLI-TIER-throw-warning-regarding-the-removal-of-the-.patch
Patch0152: 0152-bitrot-cli-Add-ondemand-scrub-event.patch
Patch0153: 0153-glusterd-use-GF_BRICK_STOPPING-as-intermediate-brick.patch
Patch0154: 0154-features-shard-Fill-loc.pargfid-too-for-named-lookup.patch
Patch0155: 0155-eventsapi-Fix-sending-event-during-volume-set-help.patch
Patch0156: 0156-glusterd-quota-upgrade-quota.conf-file-during-an-upg.patch
Patch0157: 0157-posix-acl-check-dictionary-before-using-it.patch
Patch0158: 0158-Revert-rpc-Fix-the-race-between-notification-and-rec.patch
Patch0159: 0159-performance-open-behind-Avoid-deadlock-in-statedump.patch
Patch0160: 0160-commn-HA-Add-portblock-RA-to-tickle-packets-post-fai.patch
Patch0161: 0161-build-incorrect-Requires-for-portblock-resource-agen.patch
Patch0162: 0162-build-Update-version-check-for-resource-agents-on-RH.patch
Patch0163: 0163-cluster-afr-When-failing-fop-due-to-lack-of-quorum-a.patch
Patch0164: 0164-glusterfsd-Continuous-errors-are-getting-in-mount-lo.patch
Patch0165: 0165-nfs-cli-add-warning-message-while-enabling-gluster-n.patch
Patch0166: 0166-nfs-revalidate-lookup-converted-to-fresh-lookup.patch
Patch0167: 0167-geo-rep-cli-Validate-Checkpoint-label.patch
Patch0168: 0168-performance-write-behind-fix-flush-stuck-by-former-f.patch
Patch0169: 0169-nfs-ganesha-common-ha-remove-etc-corosysnc-corosync..patch
Patch0170: 0170-protocol-client-Fix-iobref-and-iobuf-leaks-in-COMPOU.patch
Patch0171: 0171-nfs-ganesha-common-ha-grace-monitor-timed-out-unknow.patch
Patch0172: 0172-cli-rebalance-remove-brick-status-is-incorrect.patch
Patch0173: 0173-cluster-dht-Check-for-null-inode.patch
Patch0174: 0174-cli-Print-to-screen-frequently.patch
Patch0175: 0175-events-Add-FMT_WARN-for-gf_event.patch
Patch0176: 0176-upcall-Fix-a-log-level.patch
Patch0177: 0177-marker-Fix-inode-value-in-loc-in-setxattr-fop.patch
Patch0178: 0178-snapshot-scheduler-Removing-dependency-of-scheduler-.patch
Patch0179: 0179-glusterd-gNFS-On-post-upgrade-to-3.2-disable-gNFS-fo.patch
Patch0180: 0180-build-Add-dependency-on-netstat-for-glusterfs-ganesh.patch
Patch0181: 0181-afr-dht-ec-Replace-GF_EVENT_CHILD_MODIFIED-with-even.patch
Patch0182: 0182-cluster-dht-Set-layout-after-mkdir-as-root.patch
Patch0183: 0183-Undo-revert-gfapi-upcall-Use-GF_CALLOC-while-allocat.patch
Patch0184: 0184-libglusterfs-add-gf_get_mem_type.patch
Patch0185: 0185-gfapi-redesign-the-public-interface-for-upcall-consu.patch
Patch0186: 0186-gfapi-add-glfs_free-to-glfs.h.patch
Patch0187: 0187-gfapi-upcall-Fix-mismatch-in-few-upcall-API-SYMVER.patch
Patch0188: 0188-glusterd-dump-volinfo-dict-in-gluster-get-state.patch
Patch0189: 0189-libglusterfs-Now-mempool-is-added-to-ctx-pool-list-u.patch
Patch0190: 0190-glusterd-fix-few-events-generation.patch
Patch0191: 0191-performance-io-threads-Exit-threads-in-fini-as-well.patch
Patch0192: 0192-ganesha-scripts-use-export-id-for-dbus-signals.patch
Patch0193: 0193-cluster-afr-Fix-deadlock-due-to-compound-fops.patch
Patch0194: 0194-cluster-afr-Handle-rpc-errors-xdr-failures-etc-with-.patch
Patch0195: 0195-cluster-afr-Fix-bugs-in-f-inodelk-f-entrylk.patch
Patch0196: 0196-afr-allow-I-O-when-favorite-child-policy-is-enabled.patch
Patch0197: 0197-geo-rep-Upgrade-conf-file-only-if-it-is-session-conf.patch
Patch0198: 0198-geo-rep-Handle-EISDIR-error-during-Unlink.patch
Patch0199: 0199-geo-rep-Handle-ENOENT-during-unlink.patch
Patch0200: 0200-features-index-Delete-granular-entry-indices-of-alre.patch
Patch0201: 0201-cluster-afr-CLI-for-granular-entry-heal-enablement-d.patch
Patch0202: 0202-afr-Fix-the-EIO-that-can-occur-in-afr_inode_refresh-.patch
Patch0203: 0203-geo-rep-Fix-Last-synced-status-column-issue-during-H.patch
Patch0204: 0204-eventsapi-Auto-reload-Webhooks-data-when-modified.patch
Patch0205: 0205-libglusterfs-Fix-a-read-hang.patch
Patch0206: 0206-cluster-dht-A-hard-link-is-lost-during-rebalance-loo.patch
Patch0207: 0207-protocol-server-Fix-mem-leaks-in-compound-fops.patch
Patch0208: 0208-gfapi-glfs_subvol_done-should-NOT-wait-for-graph-mig.patch
Patch0209: 0209-uss-snapd-should-enable-SSL-if-SSL-is-enabled-on-vol.patch
Patch0210: 0210-common-HA-Increase-timeout-for-portblock-RA-of-actio.patch
Patch0211: 0211-glusterd-cli-Fix-volume-options-output-format-in-get.patch
Patch0212: 0212-performance-write-behind-remove-the-request-from-lia.patch
Patch0213: 0213-build-add-systemd-dependency-to-the-glusterfs-sub-pa.patch
Patch0214: 0214-cluster-tier-handle-fast-demotions.patch
Patch0215: 0215-selfheal-fix-memory-leak-on-client-side-healing-queu.patch
Patch0216: 0216-geo-rep-eventsapi-Add-Master-node-information-in-Geo.patch
Patch0217: 0217-eventsapi-JSON-output-and-different-error-codes.patch
Patch0218: 0218-eventsapi-Push-Messages-to-Webhooks-in-parallel.patch
Patch0219: 0219-cluster-ec-Check-xdata-to-avoid-memory-leak.patch
Patch0220: 0220-dht-rename-Incase-of-failure-remove-linkto-file-prop.patch
Patch0221: 0221-ganesha-scripts-avoid-incrementing-Export-Id-value-f.patch
Patch0222: 0222-common-ha-IPaddr-RA-is-not-stopped-when-pacemaker-qu.patch
Patch0223: 0223-common-ha-add-cluster-HA-status-to-status-output-for.patch
Patch0224: 0224-dht-md-cache-Filter-invalidate-if-the-file-is-made-a.patch
Patch0225: 0225-extras-Include-shard-and-full-data-heal-in-virt-grou.patch
Patch0226: 0226-afr-client-More-mem-leak-fixes-in-COMPOUND-fop-cbk.patch
Patch0227: 0227-rpc-fix-for-race-between-rpc-and-protocol-client.patch
Patch0228: 0228-afr-fix-bug-in-passing-child-index-in-afr_inode_writ.patch
Patch0229: 0229-cluster-afr-Serialize-conflicting-locks-on-all-subvo.patch
Patch0230: 0230-glusterd-ganesha-handle-volume-reset-properly-for-ga.patch
Patch0231: 0231-glusterfsd-fix-null-pointer-dereference-in-glusterfs.patch
Patch0232: 0232-cluster-afr-Remove-backward-compatibility-for-locks-.patch
Patch0233: 0233-glusterd-geo-rep-Fix-glusterd-crash.patch
Patch0234: 0234-cluster-dht-Fix-memory-corruption-while-accessing-re.patch
Patch0235: 0235-ganesha-scripts-find-export-id-for-already-exported-.patch
Patch0236: 0236-syncop-fix-conditional-wait-bug-in-parallel-dir-scan.patch
Patch0237: 0237-cluster-afr-Fix-per-txn-optimistic-changelog-initial.patch
Patch0238: 0238-snapshot-ganesha-Copy-export.conf-only-if-ganesha.en.patch
Patch0239: 0239-glusterd-Handle-volinfo-refcnt-properly-during-volum.patch
Patch0240: 0240-common-ha-Create-portblock-RA-as-part-of-add-delete-.patch
Patch0241: 0241-cluster-ec-Fix-lk-owner-set-race-in-ec_unlock.patch
Patch0242: 0242-common-ha-explicitly-set-udpu-transport-for-corosync.patch
Patch0243: 0243-glfsheal-Explicitly-enable-self-heal-xlator-options.patch
Patch0244: 0244-common-ha-add-node-create-new-node-dirs-in-shared-st.patch
Patch0245: 0245-glusterd-gNFS-explicitly-set-nfs.disable-to-off-afte.patch
Patch0246: 0246-protocol-client-fix-op_errno-handling-was-unused-var.patch
Patch0247: 0247-snapshot-Fix-restore-rollback-to-reassign-snap-volum.patch
Patch0248: 0248-client-server-Free-xdr-allocated-compound-req-rsp-ar.patch
Patch0249: 0249-socket-socket-disconnect-should-wait-for-poller-thre.patch
Patch0250: 0250-afr-Ignore-event_generation-checks-post-inode-refres.patch
Patch0251: 0251-storage-posix-Do-not-create-a-directory-which-alread.patch
Patch0252: 0252-Fixes-GlusterFS-process-crashes-on-deep-directory-hi.patch
Patch0253: 0253-ganesha-scripts-Prevent-removal-of-entries-in-ganesh.patch
Patch0254: 0254-common-ha-Correct-the-VIP-assigned-to-the-new-node-a.patch
Patch0255: 0255-performance-readdir-ahead-limit-cache-size.patch
Patch0256: 0256-dht-rebalance-reverify-lookup-failures.patch
Patch0257: 0257-performance-readdir-ahead-fix-compiler-error.patch
Patch0258: 0258-afr-use-accused-matrix-instead-of-readable-matrix-fo.patch
Patch0259: 0259-cluster-afr-Fix-missing-name-indices-due-to-EEXIST-e.patch
Patch0260: 0260-performance-readdir-ahead-mark-two-options-as-NO_DOC.patch
Patch0261: 0261-glusterd-spawn-nfs-daemon-in-op-version-bump-if-nfs..patch
Patch0262: 0262-eventsapi-Use-getaddrinfo-instead-of-gethostbyname.patch
Patch0263: 0263-ec-Invalidations-in-disperse-volume-should-not-updat.patch
Patch0264: 0264-cluster-dht-Do-rename-cleanup-as-root.patch
Patch0265: 0265-cluster-ec-Do-lookup-on-an-existing-file-in-link.patch
Patch0266: 0266-glusterd-Fail-add-brick-on-replica-count-change-if-b.patch
Patch0267: 0267-dht-rebalance-remove-errno-check-for-failure-detecti.patch
Patch0268: 0268-cluster-dht-Incorrect-migration-checks-in-fsync.patch
Patch0269: 0269-afr-Avoid-resetting-event_gen-when-brick-is-always-d.patch
Patch0270: 0270-cluster-afr-Do-not-log-of-split-brain-when-there-isn.patch
Patch0271: 0271-upcall-Resolve-dict-leak-from-up_-f-remove-set-xattr.patch
Patch0272: 0272-Fixes-upgrade-issue-in-quota.conf.patch
Patch0273: 0273-features-changelog-Fix-htime-xattr-during-brick-cras.patch
Patch0274: 0274-cluster-ec-Do-not-start-heal-on-good-file-while-IO-i.patch
Patch0275: 0275-cluster-disperse-Do-not-log-fop-failed-for-lockless-.patch
Patch0276: 0276-common-ha-All-statd-related-files-need-to-be-owned-b.patch
Patch0277: 0277-cluster-ec-Fix-cthon-failures-observed-with-ec-volum.patch
Patch0278: 0278-tools-glusterfind-delete-temporary-folder.patch
Patch0279: 0279-glusterd-regenerate-volfiles-on-op-version-bump-up.patch
Patch0280: 0280-cluster-ec-Change-level-of-messages-to-DEBUG.patch
Patch0281: 0281-rpc-socket.c-Bonnie-hangs-during-rewrites-in-ganesha.patch
Patch0282: 0282-performance-write-behind-access-stub-only-if-availab.patch
Patch0283: 0283-glusterd-do-not-load-io-threads-in-client-graph-for-.patch
Patch0284: 0284-extras-Provide-group-set-for-md-cache-and-invalidati.patch
Patch0285: 0285-socket-GF_REF_PUT-should-be-called-outside-lock.patch
Patch0286: 0286-afr-all-children-of-AFR-must-be-up-to-resolve-s-brai.patch
Patch0287: 0287-glusterd-ignore-return-code-of-glusterd_restart_bric.patch
Patch0288: 0288-protocol-client-Fix-double-free-of-client-fdctx-dest.patch
Patch0289: 0289-gNFS-Keep-the-mountdict-as-long-as-the-service-is-ac.patch
Patch0290: 0290-geo-rep-Fix-xsync-crawl.patch
Patch0291: 0291-rpcsvc-Add-rpchdr-and-proghdr-to-iobref-before-submi.patch
Patch0292: 0292-cluster-afr-Perform-new-entry-mark-before-creating-n.patch
Patch0293: 0293-extras-Add-more-options-to-group-virt.patch
Patch0294: 0294-marker-Fix-inode-value-in-loc-in-setxattr-fop.patch
Patch0295: 0295-common-ha-unable-to-start-HA-Connection-Error.patch
Patch0296: 0296-features-shard-Put-onus-of-choosing-the-inode-to-res.patch
Patch0297: 0297-features-shard-Fix-EIO-error-on-add-brick.patch
Patch0298: 0298-ganesha-scripts-restart-pcs-cluster-during-add-node.patch
Patch0299: 0299-cluster-ec-Don-t-trigger-data-metadata-heal-on-Looku.patch
Patch0300: 0300-common-ha-setup-after-teardown-often-fails.patch
Patch0301: 0301-rpc-clnt-remove-locks-while-notifying-CONNECT-DISCON.patch
Patch0302: 0302-cluster-ec-Introduce-optimistic-changelog-in-EC.patch
Patch0303: 0303-cluster-ec-Don-t-mark-dirty-on-entry-meta-ops-in-que.patch
Patch0304: 0304-features-shard-Pass-the-correct-iatt-for-cache-inval.patch
Patch0305: 0305-rpc-bump-up-conn-cleanup_gen-in-rpc_clnt_reconnect_c.patch
Patch0306: 0306-glusterd-Fix-snapshot-failure-in-non-root-geo-rep-se.patch
Patch0307: 0307-nfs-make-subdir-mounting-work-for-Solaris-10-clients.patch
Patch0308: 0308-features-shard-Fix-vm-corruption-upon-fix-layout.patch
Patch0309: 0309-features-shard-Initialize-local-fop-in-readv.patch
Patch0310: 0310-glusterd-geo-rep-Fix-snapshot-create-in-geo-rep-setu.patch
Patch0311: 0311-cluster-dht-rm-rf-fails-if-dir-has-stale-linkto-file.patch
Patch0312: 0312-cluster-dht-Remove-redundant-logs-in-dht-rmdir.patch
Patch0313: 0313-cluster-dht-Pass-the-req-dict-instead-of-NULL-in-dht.patch
Patch0314: 0314-cluster-dht-Pass-the-correct-xdata-in-fremovexattr-f.patch
Patch0315: 0315-cluster-dht-Fix-crash-in-dht-rmdir.patch
Patch0316: 0316-Revert-nfs-make-subdir-mounting-work-for-Solaris-10-.patch
Patch0317: 0317-libglusterfs-extract-some-functionality-to-functions.patch
Patch0318: 0318-fuse-implement-oauto_unmount.patch
Patch0319: 0319-cluster-dht-Fix-crash-in-dht_rmdir_cached_lookup_cbk.patch

%description
GlusterFS is a distributed file-system capable of scaling to several
petabytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file
system. GlusterFS is one of the most sophisticated file systems in
terms of features and extensibility.  It borrows a powerful concept
called Translators from GNU Hurd kernel. Much of the code in GlusterFS
is in user space and easily manageable.

This package includes the glusterfs binary, the glusterfsd daemon and the
libglusterfs and glusterfs translator modules common to both GlusterFS server
and client framework.

%package api
Summary:          GlusterFS api library
Group:            System Environment/Daemons
Requires:         %{name}%{?_isa} = %{version}-%{release}
Requires:         %{name}-client-xlators%{?_isa} = %{version}-%{release}

%description api
GlusterFS is a distributed file-system capable of scaling to several
petabytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file
system. GlusterFS is one of the most sophisticated file systems in
terms of features and extensibility.  It borrows a powerful concept
called Translators from GNU Hurd kernel. Much of the code in GlusterFS
is in user space and easily manageable.

This package provides the glusterfs libgfapi library.

%package api-devel
Summary:          Development Libraries
Group:            Development/Libraries
Requires:         %{name}%{?_isa} = %{version}-%{release}
Requires:         %{name}-devel%{?_isa} = %{version}-%{release}
Requires:         libacl-devel

%description api-devel
GlusterFS is a distributed file-system capable of scaling to several
petabytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file
system. GlusterFS is one of the most sophisticated file systems in
terms of features and extensibility.  It borrows a powerful concept
called Translators from GNU Hurd kernel. Much of the code in GlusterFS
is in user space and easily manageable.

This package provides the api include files.

%package cli
Summary:          GlusterFS CLI
Group:            Applications/File
Requires:         %{name}-libs%{?_isa} = %{version}-%{release}

%description cli
GlusterFS is a distributed file-system capable of scaling to several
petabytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file
system. GlusterFS is one of the most sophisticated file systems in
terms of features and extensibility.  It borrows a powerful concept
called Translators from GNU Hurd kernel. Much of the code in GlusterFS
is in user space and easily manageable.

This package provides the GlusterFS CLI application and its man page

%package devel
Summary:          Development Libraries
Group:            Development/Libraries
Requires:         %{name}%{?_isa} = %{version}-%{release}
# Needed for the Glupy examples to work
%if ( 0%{!?_without_extra_xlators:1} )
Requires:         %{name}-extra-xlators = %{version}-%{release}
%endif

%description devel
GlusterFS is a distributed file-system capable of scaling to several
petabytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file
system. GlusterFS is one of the most sophisticated file systems in
terms of features and extensibility.  It borrows a powerful concept
called Translators from GNU Hurd kernel. Much of the code in GlusterFS
is in user space and easily manageable.

This package provides the development libraries and include files.

%if ( 0%{!?_without_extra_xlators:1} )
%package extra-xlators
Summary:          Extra Gluster filesystem Translators
Group:            Applications/File
# We need python-gluster rpm for gluster module's __init__.py in Python
# site-packages area
Requires:         python-gluster = %{version}-%{release}
Requires:         python python-ctypes

%description extra-xlators
GlusterFS is a distributed file-system capable of scaling to several
petabytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file
system. GlusterFS is one of the most sophisticated file systems in
terms of features and extensibility.  It borrows a powerful concept
called Translators from GNU Hurd kernel. Much of the code in GlusterFS
is in user space and easily manageable.

This package provides extra filesystem Translators, such as Glupy,
for GlusterFS.
%endif

%package fuse
Summary:          Fuse client
Group:            Applications/File
BuildRequires:    fuse-devel
Requires:         attr
Requires:         psmisc

Requires:         %{name}%{?_isa} = %{version}-%{release}
Requires:         %{name}-client-xlators%{?_isa} = %{version}-%{release}

Obsoletes:        %{name}-client < %{version}-%{release}
Provides:         %{name}-client = %{version}-%{release}

%description fuse
GlusterFS is a distributed file-system capable of scaling to several
petabytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file
system. GlusterFS is one of the most sophisticated file systems in
terms of features and extensibility.  It borrows a powerful concept
called Translators from GNU Hurd kernel. Much of the code in GlusterFS
is in user space and easily manageable.

This package provides support to FUSE based clients and inlcudes the
glusterfs(d) binary.

%if ( 0%{?_build_server} )
%package ganesha
Summary:          NFS-Ganesha configuration
Group:            Applications/File

Requires:         %{name}-server%{?_isa} = %{version}-%{release}
Requires:         nfs-ganesha-gluster, pcs, dbus
%if ( 0%{?rhel} && 0%{?rhel} == 6 )
Requires:         cman, pacemaker, corosync
%endif
%if ( 0%{?fedora} ) || ( 0%{?rhel} && 0%{?rhel} > 5 )
# we need portblock resource-agent in 3.9.5 and later.
Requires:         resource-agents >= 3.9.5
Requires:         net-tools
%endif

%description ganesha
GlusterFS is a distributed file-system capable of scaling to several
petabytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file
system. GlusterFS is one of the most sophisticated file systems in
terms of features and extensibility.  It borrows a powerful concept
called Translators from GNU Hurd kernel. Much of the code in GlusterFS
is in user space and easily manageable.

This package provides the configuration and related files for using
NFS-Ganesha as the NFS server using GlusterFS
%endif

%if ( 0%{?_build_server} )
%if ( 0%{!?_without_georeplication:1} )
%package geo-replication
Summary:          GlusterFS Geo-replication
Group:            Applications/File
Requires:         %{name}%{?_isa} = %{version}-%{release}
Requires:         %{name}-server%{?_isa} = %{version}-%{release}
Requires:         python python-ctypes
Requires:         rsync

%description geo-replication
GlusterFS is a distributed file-system capable of scaling to several
peta-bytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file
system. GlusterFS is one of the most sophisticated file system in
terms of features and extensibility.  It borrows a powerful concept
called Translators from GNU Hurd kernel. Much of the code in GlusterFS
is in userspace and easily manageable.

This package provides support to geo-replication.
%endif
%endif

%package libs
Summary:          GlusterFS common libraries
Group:            Applications/File

%description libs
GlusterFS is a distributed file-system capable of scaling to several
petabytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file
system. GlusterFS is one of the most sophisticated file systems in
terms of features and extensibility.  It borrows a powerful concept
called Translators from GNU Hurd kernel. Much of the code in GlusterFS
is in user space and easily manageable.

This package provides the base GlusterFS libraries

%package -n python-gluster
Summary:          GlusterFS python library
Group:            Development/Tools
%if ( ! ( 0%{?rhel} && 0%{?rhel} < 6 || 0%{?sles_version} ) )
# EL5 does not support noarch sub-packages
BuildArch:        noarch
%endif
Requires:         python

%description -n python-gluster
GlusterFS is a distributed file-system capable of scaling to several
petabytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file
system. GlusterFS is one of the most sophisticated file systems in
terms of features and extensibility.  It borrows a powerful concept
called Translators from GNU Hurd kernel. Much of the code in GlusterFS
is in user space and easily manageable.

This package contains the python modules of GlusterFS and own gluster
namespace.


%if ( 0%{!?_without_rdma:1} )
%package rdma
Summary:          GlusterFS rdma support for ib-verbs
Group:            Applications/File
BuildRequires:    libibverbs-devel
BuildRequires:    librdmacm-devel >= 1.0.15
Requires:         %{name}%{?_isa} = %{version}-%{release}

%description rdma
GlusterFS is a distributed file-system capable of scaling to several
petabytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file
system. GlusterFS is one of the most sophisticated file systems in
terms of features and extensibility.  It borrows a powerful concept
called Translators from GNU Hurd kernel. Much of the code in GlusterFS
is in user space and easily manageable.

This package provides support to ib-verbs library.
%endif

%if ( 0%{?_build_server} )
%if ( 0%{!?_without_regression_tests:1} )
%package regression-tests
Summary:          Development Tools
Group:            Development/Tools
Requires:         %{name}%{?_isa} = %{version}-%{release}
Requires:         %{name}-fuse%{?_isa} = %{version}-%{release}
Requires:         %{name}-server%{?_isa} = %{version}-%{release}
## thin provisioning support
Requires:         lvm2 >= 2.02.89
Requires:         perl(App::Prove) perl(Test::Harness) gcc util-linux-ng
Requires:         python attr dbench file git libacl-devel net-tools
Requires:         nfs-utils xfsprogs yajl

%description regression-tests
The Gluster Test Framework, is a suite of scripts used for
regression testing of Gluster.
%endif
%endif

%if ( 0%{?_build_server} )
%if ( 0%{!?_without_ocf:1} )
%package resource-agents
Summary:          OCF Resource Agents for GlusterFS
License:          GPLv3+
%if ( ! ( 0%{?rhel} && 0%{?rhel} < 6 || 0%{?sles_version} ) )
# EL5 does not support noarch sub-packages
BuildArch:        noarch
%endif
# this Group handling comes from the Fedora resource-agents package
%if ( 0%{?fedora} || 0%{?centos_version} || 0%{?rhel} )
Group:            System Environment/Base
%else
Group:            Productivity/Clustering/HA
%endif
# for glusterd
Requires:         %{name}-server = %{version}-%{release}
# depending on the distribution, we need pacemaker or resource-agents
Requires:         %{_prefix}/lib/ocf/resource.d

%description resource-agents
GlusterFS is a distributed file-system capable of scaling to several
petabytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file
system. GlusterFS is one of the most sophisticated file systems in
terms of features and extensibility.  It borrows a powerful concept
called Translators from GNU Hurd kernel. Much of the code in GlusterFS
is in user space and easily manageable.

This package provides the resource agents which plug glusterd into
Open Cluster Framework (OCF) compliant cluster resource managers,
like Pacemaker.
%endif
%endif

%if ( 0%{?_build_server} )
%package server
Summary:          Clustered file-system server
Group:            System Environment/Daemons
Requires:         %{name}%{?_isa} = %{version}-%{release}
Requires:         %{name}-cli%{?_isa} = %{version}-%{release}
Requires:         %{name}-libs%{?_isa} = %{version}-%{release}
# some daemons (like quota) use a fuse-mount, glusterfsd is part of -fuse
Requires:         %{name}-fuse%{?_isa} = %{version}-%{release}
# self-heal daemon, rebalance, nfs-server etc. are actually clients
Requires:         %{name}-api%{?_isa} = %{version}-%{release}
Requires:         %{name}-client-xlators%{?_isa} = %{version}-%{release}
# psmisc for killall, lvm2 for snapshot, and nfs-utils and
# rpcbind/portmap for gnfs server
Requires:         psmisc
Requires:         lvm2
Requires:         nfs-utils
%if ( 0%{?_with_systemd:1} )
%{?systemd_requires}
%else
Requires(post):   /sbin/chkconfig
Requires(preun):  /sbin/service
Requires(preun):  /sbin/chkconfig
Requires(postun): /sbin/service
%endif
%if ( 0%{?fedora} ) || ( 0%{?rhel} && 0%{?rhel} >= 6 )
Requires:         rpcbind
%else
Requires:         portmap
%endif
%if ( 0%{?rhel} && 0%{?rhel} < 6 )
Obsoletes:        %{name}-geo-replication = %{version}-%{release}
%endif
%if ( 0%{?rhel} && 0%{?rhel} <= 6 )
Requires:         python-argparse
%endif
Requires:         pyxattr

%description server
GlusterFS is a distributed file-system capable of scaling to several
petabytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file
system. GlusterFS is one of the most sophisticated file systems in
terms of features and extensibility.  It borrows a powerful concept
called Translators from GNU Hurd kernel. Much of the code in GlusterFS
is in user space and easily manageable.

This package provides the glusterfs server daemon.
%endif

%package client-xlators
Summary:          GlusterFS client-side translators
Group:            Applications/File

%description client-xlators
GlusterFS is a distributed file-system capable of scaling to several
petabytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file
system. GlusterFS is one of the most sophisticated file systems in
terms of features and extensibility.  It borrows a powerful concept
called Translators from GNU Hurd kernel. Much of the code in GlusterFS
is in user space and easily manageable.

This package provides the translators needed on any GlusterFS client.

%if 0%{?_build_server}
%if ( 0%{!?_without_events:1} )
%package events
Summary:          GlusterFS Events
Group:            Applications/File
Requires:         %{name}-server%{?_isa} = %{version}-%{release}
Requires:         python python-requests python-prettytable
Requires:         python-gluster = %{version}-%{release}
%if ( 0%{?rhel} && 0%{?rhel} <= 6 )
Requires:         python-argparse
%endif
%if ( 0%{?_with_systemd:1} )
%{?systemd_requires}
%endif

%description events
GlusterFS Events

%endif
%endif

%prep
%setup -q -n %{name}-%{version}%{?prereltag}

# sanitization scriptlet for patches with file renames
ls %{_topdir}/SOURCES/*.patch | sort | \
while read p
do
    # if the destination file exists, its most probably stale
    # so we must remove it
    rename_to=( $(grep -i 'rename to' $p | cut -f 3 -d ' ') )
    if [ ${#rename_to[*]} -gt 0 ]; then
        for f in ${rename_to[*]}
        do
            if [ -f $f ]; then
                rm -f $f
            elif [ -d $f ]; then
                rm -rf $f
            fi
        done
    fi
    # apply the patch with 'git apply'
    git apply -p1 --exclude=rfc.sh \
                  --exclude=.gitignore \
                  --exclude=MAINTAINERS \
                  --exclude=extras/checkpatch.pl \
                  --exclude=build-aux/checkpatch.pl \
                  --exclude=tests \
                  $p
done


%build
%if ( 0%{?rhel} && 0%{?rhel} < 6 )
CFLAGS=-DUSE_INSECURE_OPENSSL
export CFLAGS
%endif
# In RHEL7 few hardening flags are available by default, however the RELRO
# default behaviour is partial, convert to full
%if ( 0%{?rhel} && 0%{?rhel} >= 7 )
LDFLAGS="$RPM_LD_FLAGS -Wl,-z,relro,-z,now"
export LDFLAGS
%else
%if ( 0%{?rhel} && 0%{?rhel} == 6 )
CFLAGS="$RPM_OPT_FLAGS -fPIE -DPIE"
LDFLAGS="$RPM_LD_FLAGS -pie -Wl,-z,relro,-z,now"
%else
#It appears that with gcc-4.1.2 in RHEL5 there is an issue using both -fPIC and
 # -fPIE that makes -z relro not work; -fPIE seems to undo what -fPIC does
CFLAGS="$CFLAGS $RPM_OPT_FLAGS"
LDFLAGS="$RPM_LD_FLAGS -Wl,-z,relro,-z,now"
%endif
export CFLAGS
export LDFLAGS
%endif

./autogen.sh && %configure \
        %{?_with_cmocka} \
        %{?_with_debug} \
        %{?_with_tmpfilesdir} \
        %{?_without_bd} \
        %{?_without_epoll} \
        %{?_without_fusermount} \
        %{?_without_georeplication} \
        %{?_with_firewalld} \
        %{?_without_ocf} \
        %{?_without_rdma} \
        %{?_without_syslog} \
        %{?_without_tiering} \
        %{?_without_events}

# fix hardening and remove rpath in shlibs
%if ( 0%{?fedora} && 0%{?fedora} > 17 ) || ( 0%{?rhel} && 0%{?rhel} > 6 )
sed -i 's| \\\$compiler_flags |&\\\$LDFLAGS |' libtool
%endif
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|' libtool

make %{?_smp_mflags}

%check
make check

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
# Install include directory
install -p -m 0644 contrib/uuid/*.h \
    %{buildroot}%{_includedir}/glusterfs/
%if ( 0%{_for_fedora_koji_builds} )
install -D -p -m 0644 %{SOURCE1} \
    %{buildroot}%{_sysconfdir}/sysconfig/glusterd
install -D -p -m 0644 %{SOURCE2} \
    %{buildroot}%{_sysconfdir}/sysconfig/glusterfsd
%else
install -D -p -m 0644 extras/glusterd-sysconfig \
    %{buildroot}%{_sysconfdir}/sysconfig/glusterd
%endif

%if ( 0%{_for_fedora_koji_builds} )
%if ( 0%{?rhel} && 0%{?rhel} <= 5 )
install -D -p -m 0755 %{SOURCE6} \
    %{buildroot}%{_sysconfdir}/sysconfig/modules/glusterfs-fuse.modules
%endif
%endif

mkdir -p %{buildroot}%{_localstatedir}/log/glusterd
mkdir -p %{buildroot}%{_localstatedir}/log/glusterfs
mkdir -p %{buildroot}%{_localstatedir}/log/glusterfsd
mkdir -p %{buildroot}%{_localstatedir}/run/gluster

# Remove unwanted files from all the shared libraries
find %{buildroot}%{_libdir} -name '*.a' -delete
find %{buildroot}%{_libdir} -name '*.la' -delete

# Remove installed docs, the ones we want are included by %%doc, in
# /usr/share/doc/glusterfs or /usr/share/doc/glusterfs-x.y.z depending
# on the distribution
%if ( 0%{?fedora} && 0%{?fedora} > 19 ) || ( 0%{?rhel} && 0%{?rhel} > 6 )
rm -rf %{buildroot}%{_pkgdocdir}/*
%else
rm -rf %{buildroot}%{_defaultdocdir}/%{name}
mkdir -p %{buildroot}%{_pkgdocdir}
%endif
head -50 ChangeLog > ChangeLog.head && mv ChangeLog.head ChangeLog
cat << EOM >> ChangeLog

More commit messages for this ChangeLog can be found at
https://forge.gluster.org/glusterfs-core/glusterfs/commits/v%{version}%{?prereltag}
EOM

# Remove benchmarking and other unpackaged files
%if ( 0%{?rhel} && 0%{?rhel} < 6 )
rm -rf %{buildroot}/benchmarking
rm -f %{buildroot}/glusterfs-mode.el
rm -f %{buildroot}/glusterfs.vim
%else
# make install always puts these in %%{_defaultdocdir}/%%{name} so don't
# use %%{_pkgdocdir}; that will be wrong on later Fedora distributions
rm -rf %{buildroot}%{_defaultdocdir}/%{name}/benchmarking
rm -f %{buildroot}%{_defaultdocdir}/%{name}/glusterfs-mode.el
rm -f %{buildroot}%{_defaultdocdir}/%{name}/glusterfs.vim
%endif

# Create working directory
mkdir -p %{buildroot}%{_sharedstatedir}/glusterd

# Update configuration file to /var/lib working directory
sed -i 's|option working-directory /etc/glusterd|option working-directory %{_sharedstatedir}/glusterd|g' \
    %{buildroot}%{_sysconfdir}/glusterfs/glusterd.vol

# Install glusterfsd .service or init.d file
%if ( 0%{_for_fedora_koji_builds} )
%_init_install %{glusterfsd_service} glusterfsd
%endif

install -D -p -m 0644 extras/glusterfs-logrotate \
    %{buildroot}%{_sysconfdir}/logrotate.d/glusterfs

%if ( 0%{!?_without_georeplication:1} )
mkdir -p %{buildroot}%{_sharedstatedir}/glusterd/geo-replication
touch %{buildroot}%{_sharedstatedir}/glusterd/geo-replication/gsyncd_template.conf
install -D -p -m 0644 extras/glusterfs-georep-logrotate \
    %{buildroot}%{_sysconfdir}/logrotate.d/glusterfs-georep
%else
rm -rf %{buildroot}%{_libexecdir}/glusterfs/gfind_missing_files/
rm -rf %{buildroot}%{_sbindir}/gfind_missing_files
%endif

touch %{buildroot}%{_sharedstatedir}/glusterd/glusterd.info
touch %{buildroot}%{_sharedstatedir}/glusterd/options
subdirs=(add-brick create copy-file delete gsync-create remove-brick reset set start stop)
for dir in ${subdirs[@]}; do
    mkdir -p %{buildroot}%{_sharedstatedir}/glusterd/hooks/1/"$dir"/{pre,post}
done
mkdir -p %{buildroot}%{_sharedstatedir}/glusterd/glustershd
mkdir -p %{buildroot}%{_sharedstatedir}/glusterd/peers
mkdir -p %{buildroot}%{_sharedstatedir}/glusterd/vols
mkdir -p %{buildroot}%{_sharedstatedir}/glusterd/nfs/run
mkdir -p %{buildroot}%{_sharedstatedir}/glusterd/bitd
mkdir -p %{buildroot}%{_sharedstatedir}/glusterd/quotad
mkdir -p %{buildroot}%{_sharedstatedir}/glusterd/scrub
mkdir -p %{buildroot}%{_sharedstatedir}/glusterd/snaps
mkdir -p %{buildroot}%{_sharedstatedir}/glusterd/ss_brick
touch %{buildroot}%{_sharedstatedir}/glusterd/nfs/nfs-server.vol
touch %{buildroot}%{_sharedstatedir}/glusterd/nfs/run/nfs.pid

find ./tests ./run-tests.sh -type f | cpio -pd %{buildroot}%{_prefix}/share/glusterfs

## Install bash completion for cli
install -p -m 0744 -D extras/command-completion/gluster.bash \
    %{buildroot}%{_sysconfdir}/bash_completion.d/gluster

%clean
rm -rf %{buildroot}

##-----------------------------------------------------------------------------
## All %%post should be placed here and keep them sorted
##
%post
/sbin/ldconfig
%if ( 0%{!?_without_syslog:1} )
%if ( 0%{?fedora} ) || ( 0%{?rhel} && 0%{?rhel} >= 6 )
%_init_restart rsyslog
%endif
%endif
exit 0

%post api
/sbin/ldconfig

%if ( 0%{?_build_server} )
%if ( 0%{!?_without_events:1} )
%post events
%_init_restart glustereventsd
%endif
%endif

%if ( 0%{?rhel} == 5 )
%post fuse
modprobe fuse
exit 0
%endif

%if ( 0%{?_build_server} )
%if ( 0%{!?_without_georeplication:1} )
%post geo-replication
if [ $1 -ge 1 ]; then
    %_init_restart glusterd
fi
exit 0
%endif
%endif

%post libs
/sbin/ldconfig

%if ( 0%{?_build_server} )
%post server
# Legacy server
%_init_enable glusterd
%if ( 0%{_for_fedora_koji_builds} )
%_init_enable glusterfsd
%endif
# ".cmd_log_history" is renamed to "cmd_history.log" in GlusterFS-3.7 .
# While upgrading glusterfs-server package form GlusterFS version <= 3.6 to
# GlusterFS version 3.7, ".cmd_log_history" should be renamed to
# "cmd_history.log" to retain cli command history contents.
if [ -f %{_localstatedir}/log/glusterfs/.cmd_log_history ]; then
    mv %{_localstatedir}/log/glusterfs/.cmd_log_history \
       %{_localstatedir}/log/glusterfs/cmd_history.log
fi

# Genuine Fedora (and EPEL) builds never put gluster files in /etc; if
# there are any files in /etc from a prior gluster.org install, move them
# to /var/lib. (N.B. Starting with 3.3.0 all gluster files are in /var/lib
# in gluster.org RPMs.) Be careful to copy them on the off chance that
# /etc and /var/lib are on separate file systems
if [ -d /etc/glusterd -a ! -h %{_sharedstatedir}/glusterd ]; then
    mkdir -p %{_sharedstatedir}/glusterd
    cp -a /etc/glusterd %{_sharedstatedir}/glusterd
    rm -rf /etc/glusterd
    ln -sf %{_sharedstatedir}/glusterd /etc/glusterd
fi

# Rename old volfiles in an RPM-standard way.  These aren't actually
# considered package config files, so %%config doesn't work for them.
if [ -d %{_sharedstatedir}/glusterd/vols ]; then
    for file in $(find %{_sharedstatedir}/glusterd/vols -name '*.vol'); do
        newfile=${file}.rpmsave
        echo "warning: ${file} saved as ${newfile}"
        cp ${file} ${newfile}
    done
fi

# add marker translator
# but first make certain that there are no old libs around to bite us
# BZ 834847
if [ -e /etc/ld.so.conf.d/glusterfs.conf ]; then
    rm -f /etc/ld.so.conf.d/glusterfs.conf
    /sbin/ldconfig
fi

%if (0%{?_with_firewalld:1})
#reload service files if firewalld running
if $(systemctl is-active firewalld 1>/dev/null 2>&1); then
  #firewalld-filesystem is not available for rhel7, so command used for reload.
  firewall-cmd  --reload 1>/dev/null 2>&1
fi
%endif

pidof -c -o %PPID -x glusterd &> /dev/null
if [ $? -eq 0 ]; then
    kill -9 `pgrep -f gsyncd.py` &> /dev/null

    killall --wait glusterd &> /dev/null
    glusterd --xlator-option *.upgrade=on -N

    #Cleaning leftover glusterd socket file which is created by glusterd in
    #rpm_script_t context.
    rm -rf /var/run/glusterd.socket

    # glusterd _was_ running, we killed it, it exited after *.upgrade=on,
    # so start it again
    %_init_start glusterd
else
    glusterd --xlator-option *.upgrade=on -N

    #Cleaning leftover glusterd socket file which is created by glusterd in
    #rpm_script_t context.
    rm -rf /var/run/glusterd.socket
fi
%endif

##-----------------------------------------------------------------------------
## All %%preun should be placed here and keep them sorted
##
%if ( 0%{?_build_server} )
%if ( 0%{!?_without_events:1} )
%preun events
if [ $1 -eq 0 ]; then
    if [ -f %_init_glustereventsd ]; then
        %_init_stop glustereventsd
        %_init_disable glustereventsd
    fi
fi
exit 0
%endif
%endif

%if ( 0%{?_build_server} )
%preun server
if [ $1 -eq 0 ]; then
    if [ -f %_init_glusterfsd ]; then
        %_init_stop glusterfsd
    fi
    %_init_stop glusterd
    if [ -f %_init_glusterfsd ]; then
        %_init_disable glusterfsd
    fi
    %_init_disable glusterd
fi
if [ $1 -ge 1 ]; then
    if [ -f %_init_glusterfsd ]; then
        %_init_restart glusterfsd
    fi
    %_init_restart glusterd
fi
%endif

##-----------------------------------------------------------------------------
## All %%postun should be placed here and keep them sorted
##
%postun
/sbin/ldconfig
%if ( 0%{!?_without_syslog:1} )
%if ( 0%{?fedora} ) || ( 0%{?rhel} && 0%{?rhel} >= 6 )
%_init_restart rsyslog
%endif
%endif

%postun api
/sbin/ldconfig

%postun libs
/sbin/ldconfig

%if ( 0%{?_build_server} )
%postun server
/sbin/ldconfig
%if (0%{?_with_firewalld:1})
#reload service files if firewalld running
if $(systemctl is-active firewalld 1>/dev/null 2>&1); then
    firewall-cmd  --reload
fi
%endif
exit 0
%endif

##-----------------------------------------------------------------------------
## All %%files should be placed here and keep them grouped
##
%files
# exclude extra-xlators files
%if ( ! 0%{!?_without_extra_xlators:1} )
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/encryption/rot-13.so
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/glupy.so
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/mac-compat.so
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/prot_client.so
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/prot_dht.so
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/prot_server.so
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/quiesce.so
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/testing/features/template.so
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/testing/performance/symlink-cache.so
%exclude %{python_sitelib}/*
%endif
# exclude regression-tests files
%if ( ! 0%{!?_without_regression_tests:1} )
%exclude %{_prefix}/share/glusterfs/run-tests.sh
%exclude %{_prefix}/share/glusterfs/tests/*
%endif
%if ( ! 0%{?_build_server} )
# exclude ganesha files
%exclude %{_sysconfdir}/ganesha/*
%exclude %{_libexecdir}/ganesha/*
%exclude %{_prefix}/lib/ocf/*
# exclude incrementalapi
%exclude %{_libexecdir}/glusterfs/*
%exclude %{_sbindir}/gfind_missing_files
%exclude %{_libexecdir}/glusterfs/glusterfind
%exclude %{_bindir}/glusterfind
%exclude %{_libexecdir}/glusterfs/peer_add_secret_pub
# exclude eventsapi files
%exclude %{_sysconfdir}/glusterfs/eventsconfig.json
%exclude %{_sharedstatedir}/glusterd/events
%exclude %{_libexecdir}/glusterfs/events
%exclude %{_libexecdir}/glusterfs/peer_eventsapi.py*
%exclude %{_sbindir}/glustereventsd
%exclude %{_sbindir}/gluster-eventsapi
%exclude %{_datadir}/glusterfs/scripts/eventsdash.py*
%if ( 0%{?_with_systemd:1} )
%exclude %{_unitdir}/glustereventsd.service
%else
%exclude %{_sysconfdir}/init.d/glustereventsd
%endif
# exclude server files
%exclude %{_sharedstatedir}/glusterd/*
%exclude %{_sysconfdir}/glusterfs
%exclude %{_sysconfdir}/glusterfs/glusterd.vol
%exclude %{_sysconfdir}/glusterfs/glusterfs-georep-logrotate
%exclude %{_sysconfdir}/glusterfs/glusterfs-logrotate
%exclude %{_sysconfdir}/glusterfs/gluster-rsyslog-5.8.conf
%exclude %{_sysconfdir}/glusterfs/gluster-rsyslog-7.2.conf
%exclude %{_sysconfdir}/glusterfs/group-virt.example
%exclude %{_sysconfdir}/glusterfs/group-metadata-cache
%exclude %{_sysconfdir}/glusterfs/logger.conf.example
%exclude %_init_glusterd
%exclude %{_sysconfdir}/sysconfig/glusterd
%exclude %{_bindir}/glusterfind
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/cluster/pump.so
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/arbiter.so
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/bit-rot.so
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/bitrot-stub.so
%if ( 0%{!?_without_tiering:1} )
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/changetimerecorder.so
%endif
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/index.so
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/leases.so
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/locks.so
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/posix*
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/snapview-server.so
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/marker.so
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/quota*
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/trash.so
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/upcall.so
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/mgmt*
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/nfs*
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/performance/decompounder.so
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/protocol/server*
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/storage*
%if ( 0%{!?_without_tiering:1} )
%exclude %{_libdir}/libgfdb.so.*
%endif
%exclude %{_sbindir}/gcron.py
%exclude %{_sbindir}/glfsheal
%exclude %{_sbindir}/glusterd
%exclude %{_sbindir}/snap_scheduler.py
%exclude %{_datadir}/glusterfs/scripts/stop-all-gluster-processes.sh
%exclude %{_sbindir}/conf.py*
%if 0%{?_tmpfilesdir:1}
%exclude %{_tmpfilesdir}/gluster.conf
%endif
%if ( 0%{?_with_firewalld:1} )
%exclude /usr/lib/firewalld/services/glusterfs.xml
%endif
%endif
%doc ChangeLog COPYING-GPLV2 COPYING-LGPLV3 INSTALL README.md THANKS
%{_mandir}/man8/*gluster*.8*
%exclude %{_mandir}/man8/gluster.8*
%dir %{_localstatedir}/log/glusterfs
%if ( 0%{!?_without_rdma:1} )
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/rpc-transport/rdma*
%endif
%dir %{_datadir}/glusterfs/scripts
%{_datadir}/glusterfs/scripts/post-upgrade-script-for-quota.sh
%{_datadir}/glusterfs/scripts/pre-upgrade-script-for-quota.sh
# xlators that are needed on the client- and on the server-side
%dir %{_libdir}/glusterfs/%{version}%{?prereltag}/auth
%{_libdir}/glusterfs/%{version}%{?prereltag}/auth/addr.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/auth/login.so
%dir %{_libdir}/glusterfs/%{version}%{?prereltag}/rpc-transport
%{_libdir}/glusterfs/%{version}%{?prereltag}/rpc-transport/socket.so
%dir %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/debug
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/debug/error-gen.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/debug/io-stats.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/debug/trace.so
%if ( ! ( 0%{?rhel} && 0%{?rhel} < 6 ) )
# RHEL-5 based distributions have a too old openssl
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/encryption/crypt.so
%endif
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/access-control.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/barrier.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/cdc.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/changelog.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/gfid-access.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/read-only.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/shard.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/snapview-client.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/worm.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/meta.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/performance/io-cache.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/performance/io-threads.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/performance/md-cache.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/performance/open-behind.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/performance/quick-read.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/performance/read-ahead.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/performance/readdir-ahead.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/performance/stat-prefetch.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/performance/write-behind.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/system/posix-acl.so
%dir %{_localstatedir}/run/gluster
%if 0%{?_tmpfilesdir:1}
%{_tmpfilesdir}/gluster.conf
%endif

%files api
%exclude %{_libdir}/*.so
# libgfapi files
%{_libdir}/libgfapi.*
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/mount/api.so

%files api-devel
%{_libdir}/pkgconfig/glusterfs-api.pc
%{_libdir}/libgfapi.so
%{_includedir}/glusterfs/api/*

%files cli
%{_sbindir}/gluster
%{_mandir}/man8/gluster.8*
%{_sysconfdir}/bash_completion.d/gluster

%files devel
%dir %{_includedir}/glusterfs
%{_includedir}/glusterfs/*
%exclude %{_includedir}/glusterfs/api
%exclude %{_libdir}/libgfapi.so
%if ( ! 0%{?_build_server} )
%exclude %{_libdir}/libgfchangelog.so
%endif
%if ( 0%{!?_without_tiering:1} && ! 0%{?_build_server})
%exclude %{_libdir}/libgfdb.so
%endif
%{_libdir}/*.so
# Glupy Translator examples
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/glupy/debug-trace.*
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/glupy/helloworld.*
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/glupy/negative.*
%if ( 0%{?_build_server} )
%{_libdir}/pkgconfig/libgfchangelog.pc
%else
%exclude %{_libdir}/pkgconfig/libgfchangelog.pc
%endif
%if ( 0%{!?_without_tiering:1} && ! 0%{?_build_server})
%exclude %{_libdir}/libgfdb.so
%endif
%if ( 0%{!?_without_tiering:1} && 0%{?_build_server})
%{_libdir}/pkgconfig/libgfdb.pc
%else
%if ( 0%{?rhel} && 0%{?rhel} >= 6 )
%exclude %{_libdir}/pkgconfig/libgfdb.pc
%endif
%endif

%files client-xlators
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/cluster/*.so
%exclude %{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/cluster/pump.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/protocol/client.so

%if ( 0%{!?_without_extra_xlators:1} )
%files extra-xlators
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/encryption/rot-13.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/glupy.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/mac-compat.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/prot_client.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/prot_dht.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/prot_server.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/quiesce.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/testing/features/template.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/testing/performance/symlink-cache.so
# Glupy Python files
%{python_sitelib}/gluster/glupy/*
# Don't expect a .egg-info file on EL5
%if ( ! ( 0%{?rhel} && 0%{?rhel} < 6 ) )
%{python_sitelib}/glusterfs_glupy*.egg-info
%endif
%endif

%files fuse
# glusterfs is a symlink to glusterfsd, -server depends on -fuse.
%{_sbindir}/glusterfs
%{_sbindir}/glusterfsd
%config(noreplace) %{_sysconfdir}/logrotate.d/glusterfs
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/mount/fuse.so
/sbin/mount.glusterfs
%if ( 0%{!?_without_fusermount:1} )
%{_bindir}/fusermount-glusterfs
%endif
%if ( 0%{_for_fedora_koji_builds} )
%if ( 0%{?rhel} && 0%{?rhel} <= 5 )
%{_sysconfdir}/sysconfig/modules/glusterfs-fuse.modules
%endif
%endif

%if ( 0%{?_build_server} )
%files ganesha
%{_sysconfdir}/ganesha/*
%{_libexecdir}/ganesha/*
%{_prefix}/lib/ocf/resource.d/heartbeat/*
%{_sharedstatedir}/glusterd/hooks/1/start/post/S31ganesha-start.sh
%endif

%if ( 0%{?_build_server} )
%if ( 0%{!?_without_georeplication:1} )
%files geo-replication
%config(noreplace) %{_sysconfdir}/logrotate.d/glusterfs-georep

%{_sbindir}/gfind_missing_files
%{_sbindir}/gluster-mountbroker
%{_libexecdir}/glusterfs/gsyncd
%{_libexecdir}/glusterfs/python/syncdaemon/*
%{_libexecdir}/glusterfs/gverify.sh
%{_libexecdir}/glusterfs/set_geo_rep_pem_keys.sh
%{_libexecdir}/glusterfs/peer_gsec_create
%{_libexecdir}/glusterfs/peer_mountbroker
%{_libexecdir}/glusterfs/peer_mountbroker.py*
%{_libexecdir}/glusterfs/gfind_missing_files

       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/geo-replication
%ghost      %attr(0644,-,-) %{_sharedstatedir}/glusterd/geo-replication/gsyncd_template.conf
       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/gsync-create
       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/gsync-create/post
            %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/gsync-create/post/S56glusterd-geo-rep-create-post.sh
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/gsync-create/pre

%{_datadir}/glusterfs/scripts/get-gfid.sh
%{_datadir}/glusterfs/scripts/slave-upgrade.sh
%{_datadir}/glusterfs/scripts/gsync-upgrade.sh
%{_datadir}/glusterfs/scripts/generate-gfid-file.sh
%{_datadir}/glusterfs/scripts/gsync-sync-gfid
%{_datadir}/glusterfs/scripts/schedule_georep.py*
%endif
%endif

%files libs
%{_libdir}/*.so.*
%exclude %{_libdir}/libgfapi.*
%if ( 0%{!?_without_tiering:1} )
# libgfdb is only needed server-side
%exclude %{_libdir}/libgfdb.*
%endif

%files -n python-gluster
# introducing glusterfs module in site packages.
# so that all other gluster submodules can reside in the same namespace.
%{python_sitelib}/gluster/__init__.*
%{python_sitelib}/gluster/cliutils

%if ( 0%{!?_without_rdma:1} )
%files rdma
%{_libdir}/glusterfs/%{version}%{?prereltag}/rpc-transport/rdma*
%endif

%if ( 0%{?_build_server} )
%if ( 0%{!?_without_regression_tests:1} )
%files regression-tests
%{_prefix}/share/glusterfs/run-tests.sh
%{_prefix}/share/glusterfs/tests
%exclude %{_prefix}/share/glusterfs/tests/basic/rpm.t
%exclude %{_prefix}/share/glusterfs/tests/vagrant
%endif
%endif

%if ( 0%{?_build_server} )
%if ( 0%{!?_without_ocf:1} )
%files resource-agents
# /usr/lib is the standard for OCF, also on x86_64
%{_prefix}/lib/ocf/resource.d/glusterfs
%endif
%endif

%if ( 0%{?_build_server} )
%files server
%exclude %{_sharedstatedir}/glusterd/hooks/1/gsync-create/post/S56glusterd-geo-rep-create-post.sh
%doc extras/clear_xattrs.sh
# sysconf
%config(noreplace) %{_sysconfdir}/glusterfs
%exclude %{_sysconfdir}/glusterfs/eventsconfig.json
%config(noreplace) %{_sysconfdir}/sysconfig/glusterd
%if ( 0%{_for_fedora_koji_builds} )
%config(noreplace) %{_sysconfdir}/sysconfig/glusterfsd
%endif

# init files
%_init_glusterd
%if ( 0%{_for_fedora_koji_builds} )
%_init_glusterfsd
%endif

# binaries
%{_sbindir}/glusterd
%{_sbindir}/glfsheal
# {_sbindir}/glusterfsd is the actual binary, but glusterfs (client) is a
# symlink. The binary itself (and symlink) are part of the glusterfs-fuse
# package, because glusterfs-server depends on that anyway.
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/cluster/pump.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/arbiter.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/bit-rot.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/bitrot-stub.so
%if ( 0%{!?_without_tiering:1} )
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/changetimerecorder.so
%endif
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/index.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/locks.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/posix*
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/snapview-server.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/marker.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/quota*
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/trash.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/upcall.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/features/leases.so
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/mgmt*
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/nfs*
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/protocol/server*
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/storage*
%{_libdir}/glusterfs/%{version}%{?prereltag}/xlator/performance/decompounder.so
%if ( 0%{!?_without_tiering:1} )
%{_libdir}/libgfdb.so.*
%endif

# snap_scheduler
%{_sbindir}/snap_scheduler.py
%{_sbindir}/gcron.py
%{_sbindir}/conf.py

# /var/lib/glusterd, e.g. hookscripts, etc.
%ghost      %attr(0644,-,-) %config(noreplace) %{_sharedstatedir}/glusterd/glusterd.info
       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/bitd
       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/groups
            %attr(0644,-,-) %{_sharedstatedir}/glusterd/groups/virt
            %attr(0644,-,-) %{_sharedstatedir}/glusterd/groups/metadata-cache
       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/glusterfind
       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/glusterfind/.keys
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/glustershd
       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks
       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1
       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/add-brick
       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/add-brick/post
            %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/add-brick/post/disabled-quota-root-xattr-heal.sh
            %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/add-brick/pre/S28Quota-enable-root-xattr-heal.sh
       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/add-brick/pre
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/create
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/create/post
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/create/pre
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/copy-file
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/copy-file/post
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/copy-file/pre
       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/delete
       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/delete/post
                            %{_sharedstatedir}/glusterd/hooks/1/delete/post/S57glusterfind-delete-post
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/delete/pre
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/remove-brick
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/remove-brick/post
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/remove-brick/pre
       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/reset
       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/reset/post
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/reset/pre
       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/set
       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/set/post
            %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/set/post/S30samba-set.sh
            %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/set/post/S32gluster_enable_shared_storage.sh
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/set/pre
       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/start
       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/start/post
            %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/start/post/S29CTDBsetup.sh
            %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/start/post/S30samba-start.sh
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/start/pre
       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/stop
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/stop/post
       %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/stop/pre
            %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/stop/pre/S30samba-stop.sh
            %attr(0755,-,-) %{_sharedstatedir}/glusterd/hooks/1/stop/pre/S29CTDB-teardown.sh
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/nfs
%ghost      %attr(0600,-,-) %{_sharedstatedir}/glusterd/nfs/nfs-server.vol
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/nfs/run
%ghost      %attr(0600,-,-) %{_sharedstatedir}/glusterd/nfs/run/nfs.pid
%ghost      %attr(0600,-,-) %{_sharedstatedir}/glusterd/options
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/peers
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/quotad
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/scrub
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/snaps
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/ss_brick
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/vols

# Extra utility script
%{_datadir}/glusterfs/scripts/stop-all-gluster-processes.sh

# Incrementalapi
%{_libexecdir}/glusterfs/glusterfind
%{_bindir}/glusterfind
%{_libexecdir}/glusterfs/peer_add_secret_pub

%if ( 0%{?_with_firewalld:1} )
%{_prefix}/lib/firewalld/services/glusterfs.xml
%endif
%endif

# Events
%if 0%{?_build_server}
%if ( 0%{!?_without_events:1} )
%files events
%config(noreplace) %{_sysconfdir}/glusterfs/eventsconfig.json
%dir %attr(0755,-,-) %{_sharedstatedir}/glusterd/events
%{_libexecdir}/glusterfs/events
%{_libexecdir}/glusterfs/peer_eventsapi.py*
%{_sbindir}/glustereventsd
%{_sbindir}/gluster-eventsapi
%{_datadir}/glusterfs/scripts/eventsdash.py*
%if ( 0%{?_with_systemd:1} )
%{_unitdir}/glustereventsd.service
%else
%{_sysconfdir}/init.d/glustereventsd
%endif
%endif
%endif

##-----------------------------------------------------------------------------
## All %pretrans should be placed here and keep them sorted
##
%if 0%{?_build_server}
%pretrans -p <lua>
if not posix.access("/bin/bash", "x") then
    -- initial installation, no shell, no running glusterfsd
    return 0
end

-- TODO: move this completely to a lua script
-- For now, we write a temporary bash script and execute that.

script = [[#!/bin/sh
pidof -c -o %PPID -x glusterfsd &>/dev/null

if [ $? -eq 0 ]; then
   pushd . > /dev/null 2>&1
   for volume in /var/lib/glusterd/vols/*; do cd $volume;
       vol_type=`grep '^type=' info | awk -F'=' '{print $2}'`
       volume_started=`grep '^status=' info | awk -F'=' '{print $2}'`
       if [ $vol_type -eq 0 ] && [ $volume_started -eq 1 ] ; then
          echo "ERROR: Distribute volumes detected. In-service rolling upgrade requires distribute volume(s) to be stopped."
          echo "ERROR: Please stop distribute volume(s) before proceeding... exiting!"
          exit 1;
       fi
   done

   popd > /dev/null 2>&1
   echo "WARNING: Updating glusterfs requires its processes to be killed. This action does NOT incur downtime."
   echo "WARNING: Ensure to wait for the upgraded server to finish healing before proceeding."
   echo "WARNING: Refer upgrade section of install guide for more details"
   echo "Please run # service glusterd stop; pkill glusterfs; pkill glusterfsd; pkill gsyncd.py;"
   exit 1;
fi
]]

-- Since we run pretrans scripts only for RPMs built for a server build,
-- we can now use os.tmpname() since it is available on RHEL6 and later
-- platforms which are server platforms.
tmpname = os.tmpname()
tmpfile = io.open(tmpname, "w")
tmpfile:write(script)
tmpfile:close()
ok, how, val = os.execute("/bin/bash " .. tmpname)
os.remove(tmpname)
if not (ok == 0) then
   error("Detected running glusterfs processes", ok)
end



%pretrans api -p <lua>
if not posix.access("/bin/bash", "x") then
    -- initial installation, no shell, no running glusterfsd
    return 0
end

-- TODO: move this completely to a lua script
-- For now, we write a temporary bash script and execute that.

script = [[#!/bin/sh
pidof -c -o %PPID -x glusterfsd &>/dev/null

if [ $? -eq 0 ]; then
   pushd . > /dev/null 2>&1
   for volume in /var/lib/glusterd/vols/*; do cd $volume;
       vol_type=`grep '^type=' info | awk -F'=' '{print $2}'`
       volume_started=`grep '^status=' info | awk -F'=' '{print $2}'`
       if [ $vol_type -eq 0 ] && [ $volume_started -eq 1 ] ; then
          exit 1;
       fi
   done

   popd > /dev/null 2>&1
   exit 1;
fi
]]

-- Since we run pretrans scripts only for RPMs built for a server build,
-- we can now use os.tmpname() since it is available on RHEL6 and later
-- platforms which are server platforms.
tmpname = os.tmpname()
tmpfile = io.open(tmpname, "w")
tmpfile:write(script)
tmpfile:close()
ok, how, val = os.execute("/bin/bash " .. tmpname)
os.remove(tmpname)
if not (ok == 0) then
   error("Detected running glusterfs processes", ok)
end



%pretrans api-devel -p <lua>
if not posix.access("/bin/bash", "x") then
    -- initial installation, no shell, no running glusterfsd
    return 0
end

-- TODO: move this completely to a lua script
-- For now, we write a temporary bash script and execute that.

script = [[#!/bin/sh
pidof -c -o %PPID -x glusterfsd &>/dev/null

if [ $? -eq 0 ]; then
   pushd . > /dev/null 2>&1
   for volume in /var/lib/glusterd/vols/*; do cd $volume;
       vol_type=`grep '^type=' info | awk -F'=' '{print $2}'`
       volume_started=`grep '^status=' info | awk -F'=' '{print $2}'`
       if [ $vol_type -eq 0 ] && [ $volume_started -eq 1 ] ; then
          exit 1;
       fi
   done

   popd > /dev/null 2>&1
   exit 1;
fi
]]

-- Since we run pretrans scripts only for RPMs built for a server build,
-- we can now use os.tmpname() since it is available on RHEL6 and later
-- platforms which are server platforms.
tmpname = os.tmpname()
tmpfile = io.open(tmpname, "w")
tmpfile:write(script)
tmpfile:close()
ok, how, val = os.execute("/bin/bash " .. tmpname)
os.remove(tmpname)
if not (ok == 0) then
   error("Detected running glusterfs processes", ok)
end



%pretrans cli -p <lua>
if not posix.access("/bin/bash", "x") then
    -- initial installation, no shell, no running glusterfsd
    return 0
end

-- TODO: move this completely to a lua script
-- For now, we write a temporary bash script and execute that.

script = [[#!/bin/sh
pidof -c -o %PPID -x glusterfsd &>/dev/null

if [ $? -eq 0 ]; then
   pushd . > /dev/null 2>&1
   for volume in /var/lib/glusterd/vols/*; do cd $volume;
       vol_type=`grep '^type=' info | awk -F'=' '{print $2}'`
       volume_started=`grep '^status=' info | awk -F'=' '{print $2}'`
       if [ $vol_type -eq 0 ] && [ $volume_started -eq 1 ] ; then
          exit 1;
       fi
   done

   popd > /dev/null 2>&1
   exit 1;
fi
]]

-- Since we run pretrans scripts only for RPMs built for a server build,
-- we can now use os.tmpname() since it is available on RHEL6 and later
-- platforms which are server platforms.
tmpname = os.tmpname()
tmpfile = io.open(tmpname, "w")
tmpfile:write(script)
tmpfile:close()
ok, how, val = os.execute("/bin/bash " .. tmpname)
os.remove(tmpname)
if not (ok == 0) then
   error("Detected running glusterfs processes", ok)
end



%pretrans client-xlators -p <lua>
if not posix.access("/bin/bash", "x") then
    -- initial installation, no shell, no running glusterfsd
    return 0
end

-- TODO: move this completely to a lua script
-- For now, we write a temporary bash script and execute that.

script = [[#!/bin/sh
pidof -c -o %PPID -x glusterfsd &>/dev/null

if [ $? -eq 0 ]; then
   pushd . > /dev/null 2>&1
   for volume in /var/lib/glusterd/vols/*; do cd $volume;
       vol_type=`grep '^type=' info | awk -F'=' '{print $2}'`
       volume_started=`grep '^status=' info | awk -F'=' '{print $2}'`
       if [ $vol_type -eq 0 ] && [ $volume_started -eq 1 ] ; then
          exit 1;
       fi
   done

   popd > /dev/null 2>&1
   exit 1;
fi
]]

-- Since we run pretrans scripts only for RPMs built for a server build,
-- we can now use os.tmpname() since it is available on RHEL6 and later
-- platforms which are server platforms.
tmpname = os.tmpname()
tmpfile = io.open(tmpname, "w")
tmpfile:write(script)
tmpfile:close()
ok, how, val = os.execute("/bin/bash " .. tmpname)
os.remove(tmpname)
if not (ok == 0) then
   error("Detected running glusterfs processes", ok)
end



%pretrans devel -p <lua>
if not posix.access("/bin/bash", "x") then
    -- initial installation, no shell, no running glusterfsd
    return 0
end

-- TODO: move this completely to a lua script
-- For now, we write a temporary bash script and execute that.

script = [[#!/bin/sh
pidof -c -o %PPID -x glusterfsd &>/dev/null

if [ $? -eq 0 ]; then
   pushd . > /dev/null 2>&1
   for volume in /var/lib/glusterd/vols/*; do cd $volume;
       vol_type=`grep '^type=' info | awk -F'=' '{print $2}'`
       volume_started=`grep '^status=' info | awk -F'=' '{print $2}'`
       if [ $vol_type -eq 0 ] && [ $volume_started -eq 1 ] ; then
          exit 1;
       fi
   done

   popd > /dev/null 2>&1
   exit 1;
fi
]]

-- Since we run pretrans scripts only for RPMs built for a server build,
-- we can now use os.tmpname() since it is available on RHEL6 and later
-- platforms which are server platforms.
tmpname = os.tmpname()
tmpfile = io.open(tmpname, "w")
tmpfile:write(script)
tmpfile:close()
ok, how, val = os.execute("/bin/bash " .. tmpname)
os.remove(tmpname)
if not (ok == 0) then
   error("Detected running glusterfs processes", ok)
end



%pretrans fuse -p <lua>
if not posix.access("/bin/bash", "x") then
    -- initial installation, no shell, no running glusterfsd
    return 0
end

-- TODO: move this completely to a lua script
-- For now, we write a temporary bash script and execute that.

script = [[#!/bin/sh
pidof -c -o %PPID -x glusterfsd &>/dev/null

if [ $? -eq 0 ]; then
   pushd . > /dev/null 2>&1
   for volume in /var/lib/glusterd/vols/*; do cd $volume;
       vol_type=`grep '^type=' info | awk -F'=' '{print $2}'`
       volume_started=`grep '^status=' info | awk -F'=' '{print $2}'`
       if [ $vol_type -eq 0 ] && [ $volume_started -eq 1 ] ; then
          exit 1;
       fi
   done

   popd > /dev/null 2>&1
   exit 1;
fi
]]

-- Since we run pretrans scripts only for RPMs built for a server build,
-- we can now use os.tmpname() since it is available on RHEL6 and later
-- platforms which are server platforms.
tmpname = os.tmpname()
tmpfile = io.open(tmpname, "w")
tmpfile:write(script)
tmpfile:close()
ok, how, val = os.execute("/bin/bash " .. tmpname)
os.remove(tmpname)
if not (ok == 0) then
   error("Detected running glusterfs processes", ok)
end



%pretrans ganesha -p <lua>
if not posix.access("/bin/bash", "x") then
    -- initial installation, no shell, no running glusterfsd
    return 0
end

-- TODO: move this completely to a lua script
-- For now, we write a temporary bash script and execute that.

script = [[#!/bin/sh
pidof -c -o %PPID -x glusterfsd &>/dev/null

if [ $? -eq 0 ]; then
   pushd . > /dev/null 2>&1
   for volume in /var/lib/glusterd/vols/*; do cd $volume;
       vol_type=`grep '^type=' info | awk -F'=' '{print $2}'`
       volume_started=`grep '^status=' info | awk -F'=' '{print $2}'`
       if [ $vol_type -eq 0 ] && [ $volume_started -eq 1 ] ; then
          exit 1;
       fi
   done

   popd > /dev/null 2>&1
   exit 1;
fi
]]

-- Since we run pretrans scripts only for RPMs built for a server build,
-- we can now use os.tmpname() since it is available on RHEL6 and later
-- platforms which are server platforms.
tmpname = os.tmpname()
tmpfile = io.open(tmpname, "w")
tmpfile:write(script)
tmpfile:close()
ok, how, val = os.execute("/bin/bash " .. tmpname)
os.remove(tmpname)
if not (ok == 0) then
   error("Detected running glusterfs processes", ok)
end



%if ( 0%{!?_without_georeplication:1} )
%pretrans geo-replication -p <lua>
if not posix.access("/bin/bash", "x") then
    -- initial installation, no shell, no running glusterfsd
    return 0
end

-- TODO: move this completely to a lua script
-- For now, we write a temporary bash script and execute that.

script = [[#!/bin/sh
pidof -c -o %PPID -x glusterfsd &>/dev/null

if [ $? -eq 0 ]; then
   pushd . > /dev/null 2>&1
   for volume in /var/lib/glusterd/vols/*; do cd $volume;
       vol_type=`grep '^type=' info | awk -F'=' '{print $2}'`
       volume_started=`grep '^status=' info | awk -F'=' '{print $2}'`
       if [ $vol_type -eq 0 ] && [ $volume_started -eq 1 ] ; then
          exit 1;
       fi
   done

   popd > /dev/null 2>&1
   exit 1;
fi
]]

-- Since we run pretrans scripts only for RPMs built for a server build,
-- we can now use os.tmpname() since it is available on RHEL6 and later
-- platforms which are server platforms.
tmpname = os.tmpname()
tmpfile = io.open(tmpname, "w")
tmpfile:write(script)
tmpfile:close()
ok, how, val = os.execute("/bin/bash " .. tmpname)
os.remove(tmpname)
if not (ok == 0) then
   error("Detected running glusterfs processes", ok)
end
%endif



%pretrans libs -p <lua>
if not posix.access("/bin/bash", "x") then
    -- initial installation, no shell, no running glusterfsd
    return 0
end

-- TODO: move this completely to a lua script
-- For now, we write a temporary bash script and execute that.

script = [[#!/bin/sh
pidof -c -o %PPID -x glusterfsd &>/dev/null

if [ $? -eq 0 ]; then
   pushd . > /dev/null 2>&1
   for volume in /var/lib/glusterd/vols/*; do cd $volume;
       vol_type=`grep '^type=' info | awk -F'=' '{print $2}'`
       volume_started=`grep '^status=' info | awk -F'=' '{print $2}'`
       if [ $vol_type -eq 0 ] && [ $volume_started -eq 1 ] ; then
          exit 1;
       fi
   done

   popd > /dev/null 2>&1
   exit 1;
fi
]]

-- Since we run pretrans scripts only for RPMs built for a server build,
-- we can now use os.tmpname() since it is available on RHEL6 and later
-- platforms which are server platforms.
tmpname = os.tmpname()
tmpfile = io.open(tmpname, "w")
tmpfile:write(script)
tmpfile:close()
ok, how, val = os.execute("/bin/bash " .. tmpname)
os.remove(tmpname)
if not (ok == 0) then
   error("Detected running glusterfs processes", ok)
end



%pretrans -n python-gluster -p <lua>
if not posix.access("/bin/bash", "x") then
    -- initial installation, no shell, no running glusterfsd
    return 0
end

-- TODO: move this completely to a lua script
-- For now, we write a temporary bash script and execute that.

script = [[#!/bin/sh
pidof -c -o %PPID -x glusterfsd &>/dev/null

if [ $? -eq 0 ]; then
   pushd . > /dev/null 2>&1
   for volume in /var/lib/glusterd/vols/*; do cd $volume;
       vol_type=`grep '^type=' info | awk -F'=' '{print $2}'`
       volume_started=`grep '^status=' info | awk -F'=' '{print $2}'`
       if [ $vol_type -eq 0 ] && [ $volume_started -eq 1 ] ; then
          exit 1;
       fi
   done

   popd > /dev/null 2>&1
   exit 1;
fi
]]

-- Since we run pretrans scripts only for RPMs built for a server build,
-- we can now use os.tmpname() since it is available on RHEL6 and later
-- platforms which are server platforms.
tmpname = os.tmpname()
tmpfile = io.open(tmpname, "w")
tmpfile:write(script)
tmpfile:close()
ok, how, val = os.execute("/bin/bash " .. tmpname)
os.remove(tmpname)
if not (ok == 0) then
   error("Detected running glusterfs processes", ok)
end



%if ( 0%{!?_without_rdma:1} )
%pretrans rdma -p <lua>
if not posix.access("/bin/bash", "x") then
    -- initial installation, no shell, no running glusterfsd
    return 0
end

-- TODO: move this completely to a lua script
-- For now, we write a temporary bash script and execute that.

script = [[#!/bin/sh
pidof -c -o %PPID -x glusterfsd &>/dev/null

if [ $? -eq 0 ]; then
   pushd . > /dev/null 2>&1
   for volume in /var/lib/glusterd/vols/*; do cd $volume;
       vol_type=`grep '^type=' info | awk -F'=' '{print $2}'`
       volume_started=`grep '^status=' info | awk -F'=' '{print $2}'`
       if [ $vol_type -eq 0 ] && [ $volume_started -eq 1 ] ; then
          exit 1;
       fi
   done

   popd > /dev/null 2>&1
   exit 1;
fi
]]

-- Since we run pretrans scripts only for RPMs built for a server build,
-- we can now use os.tmpname() since it is available on RHEL6 and later
-- platforms which are server platforms.
tmpname = os.tmpname()
tmpfile = io.open(tmpname, "w")
tmpfile:write(script)
tmpfile:close()
ok, how, val = os.execute("/bin/bash " .. tmpname)
os.remove(tmpname)
if not (ok == 0) then
   error("Detected running glusterfs processes", ok)
end
%endif



%if ( 0%{!?_without_ocf:1} )
%pretrans resource-agents -p <lua>
if not posix.access("/bin/bash", "x") then
    -- initial installation, no shell, no running glusterfsd
    return 0
end

-- TODO: move this completely to a lua script
-- For now, we write a temporary bash script and execute that.

script = [[#!/bin/sh
pidof -c -o %PPID -x glusterfsd &>/dev/null

if [ $? -eq 0 ]; then
   pushd . > /dev/null 2>&1
   for volume in /var/lib/glusterd/vols/*; do cd $volume;
       vol_type=`grep '^type=' info | awk -F'=' '{print $2}'`
       volume_started=`grep '^status=' info | awk -F'=' '{print $2}'`
       if [ $vol_type -eq 0 ] && [ $volume_started -eq 1 ] ; then
          exit 1;
       fi
   done

   popd > /dev/null 2>&1
   exit 1;
fi
]]

-- Since we run pretrans scripts only for RPMs built for a server build,
-- we can now use os.tmpname() since it is available on RHEL6 and later
-- platforms which are server platforms.
tmpname = os.tmpname()
tmpfile = io.open(tmpname, "w")
tmpfile:write(script)
tmpfile:close()
ok, how, val = os.execute("/bin/bash " .. tmpname)
os.remove(tmpname)
if not (ok == 0) then
   error("Detected running glusterfs processes", ok)
end
%endif



%pretrans server -p <lua>
if not posix.access("/bin/bash", "x") then
    -- initial installation, no shell, no running glusterfsd
    return 0
end

-- TODO: move this completely to a lua script
-- For now, we write a temporary bash script and execute that.

script = [[#!/bin/sh
pidof -c -o %PPID -x glusterfsd &>/dev/null

if [ $? -eq 0 ]; then
   pushd . > /dev/null 2>&1
   for volume in /var/lib/glusterd/vols/*; do cd $volume;
       vol_type=`grep '^type=' info | awk -F'=' '{print $2}'`
       volume_started=`grep '^status=' info | awk -F'=' '{print $2}'`
       if [ $vol_type -eq 0 ] && [ $volume_started -eq 1 ] ; then
          exit 1;
       fi
   done

   popd > /dev/null 2>&1
   exit 1;
fi
]]

-- Since we run pretrans scripts only for RPMs built for a server build,
-- we can now use os.tmpname() since it is available on RHEL6 and later
-- platforms which are server platforms.
tmpname = os.tmpname()
tmpfile = io.open(tmpname, "w")
tmpfile:write(script)
tmpfile:close()
ok, how, val = os.execute("/bin/bash " .. tmpname)
os.remove(tmpname)
if not (ok == 0) then
   error("Detected running glusterfs processes", ok)
end
%endif

%changelog
* Fri Aug 04 2017 Scientific Linux Auto Patch Process <SCIENTIFIC-LINUX-DEVEL@LISTSERV.FNAL.GOV>
- Added Source: enable-server-packages.patch
-->  Enable building the glusterfs-server package

* Tue May 30 2017 Milind Changire <mchangir@redhat.com> - 3.8.4-18.4
- fixes bugs bz#1456696

* Mon May 29 2017 Milind Changire <mchangir@redhat.com> - 3.8.4-18.3
- fixes bugs bz#1456420

* Thu May 18 2017 Milind Changire <mchangir@redhat.com> - 3.8.4-18.2
- fixes bugs bz#1439731 bz#1439753 bz#1440162 bz#1445591 bz#1445593 
  bz#1447186 bz#1451200 bz#1451673

* Tue May 09 2017 Milind Changire <mchangir@redhat.com> - 3.8.4-18.1
- fixes bugs bz#1439731 bz#1439753 bz#1440162 bz#1445591 bz#1445593 
  bz#1445594 bz#1447186

* Wed Mar 08 2017 Milind Changire <mchangir@redhat.com> - 3.8.4-18
- fixes bugs bz#1408655

* Sat Mar 04 2017 Milind Changire <mchangir@redhat.com> - 3.8.4-17
- fixes bugs bz#1408655 bz#1425740

* Thu Mar 02 2017 Milind Changire <mchangir@redhat.com> - 3.8.4-16
- fixes bugs bz#1412554 bz#1424944 bz#1425748 bz#1426324 bz#1426559

* Mon Feb 20 2017 Milind Changire <mchangir@redhat.com> - 3.8.4-15
- fixes bugs bz#1205162 bz#1315544 bz#1403180 bz#1409135 bz#1415101 
  bz#1417177 bz#1418901 bz#1420635 bz#1422431

* Mon Feb 06 2017 Milind Changire <mchangir@redhat.com> - 3.8.4-14
- fixes bugs bz#1408576 bz#1408705 bz#1409563 bz#1411270 bz#1413513 
  bz#1414247 bz#1414663 bz#1415583 bz#1417955 bz#1418011

* Tue Jan 24 2017 Milind Changire <mchangir@redhat.com> - 3.8.4-13
- fixes bugs bz#1406322 bz#1408639 bz#1411329 bz#1412883 bz#1412955

* Mon Jan 16 2017 Milind Changire <mchangir@redhat.com> - 3.8.4-12
- fixes bugs bz#1410025 bz#1410406 bz#1411617

* Fri Jan 06 2017 Milind Changire <mchangir@redhat.com> - 3.8.4-11
- fixes bugs bz#1393316 bz#1404989 bz#1405000 bz#1408112 bz#1408413 
  bz#1408426 bz#1408836 bz#1409472 bz#1409782 bz#1409808

* Thu Dec 22 2016 Milind Changire <mchangir@redhat.com> - 3.8.4-10
- fixes bugs bz#1393316 bz#1398311 bz#1398798 bz#1403672 bz#1404110 
  bz#1404633 bz#1404982 bz#1405000 bz#1406025 bz#1406401

* Fri Dec 16 2016 Milind Changire <mchangir@redhat.com> - 3.8.4-9
- fixes bugs bz#1400057 bz#1400068 bz#1400093 bz#1400599 bz#1402774 
  bz#1403120 bz#1403587 bz#1403770 bz#1403840 bz#1404996 bz#1405299

* Fri Dec 09 2016 Milind Changire <mchangir@redhat.com> - 3.8.4-8
- fixes bugs bz#1393694 bz#1397450 bz#1398188 bz#1399100 bz#1400365 
  bz#1401380 bz#1401806 bz#1401817

* Mon Dec 05 2016 Milind Changire <mchangir@redhat.com> - 3.8.4-7
- fixes bugs bz#1361759 bz#1376464 bz#1377062 bz#1378131 bz#1381452 
  bz#1384070 bz#1385605 bz#1388755 bz#1395539 bz#1395603 bz#1395613 bz#1396449 
  bz#1397257 bz#1398257 bz#1398261 bz#1398315 bz#1399105 bz#1399598 bz#1399757 
  bz#1400395

* Tue Nov 29 2016 Milind Changire <mchangir@redhat.com> - 3.8.4-6
- fixes bugs bz#1337565 bz#1376694 bz#1376695 bz#1380122 bz#1380419 
  bz#1380655 bz#1382686 bz#1383898 bz#1384316 bz#1384993 bz#1385474 bz#1385589 
  bz#1385606 bz#1386127 bz#1386635 bz#1387204 bz#1387501 bz#1387558 bz#1389422 
  bz#1389661 bz#1390843 bz#1391808 bz#1392299 bz#1392837 bz#1392895 bz#1393526 
  bz#1393694 bz#1393709 bz#1393758 bz#1394219 bz#1394752 bz#1395574 bz#1396166 
  bz#1396361 bz#1397257 bz#1397286 bz#1397430 bz#1398331

* Fri Nov 11 2016 Milind Changire <mchangir@redhat.com> - 3.8.4-5
- fixes bugs bz#1278336 bz#1392899

* Thu Nov 10 2016 Milind Changire <mchangir@redhat.com> - 3.8.4-4
- fixes bugs bz#1367472 bz#1370350 bz#1379790 bz#1380742 bz#1384311 
  bz#1385525 bz#1385605 bz#1386185 bz#1386366 bz#1386472 bz#1387152 bz#1387544 
  bz#1388464 bz#1388734 bz#1389168 bz#1391093

* Mon Oct 24 2016 Milind Changire <mchangir@redhat.com> - 3.8.4-3
- fixes bugs bz#1284873 bz#1333885 bz#1336377 bz#1339765 bz#1347257 
  bz#1361513 bz#1361519 bz#1362044 bz#1374568 bz#1375465 bz#1378677 bz#1379919 
  bz#1379924 bz#1379966 bz#1380257 bz#1380276 bz#1380605 bz#1380619 bz#1380638 
  bz#1380710 bz#1381822 bz#1382277 bz#1386172 bz#1386538

* Thu Sep 29 2016 Milind Changire <mchangir@redhat.com> - 3.8.4-2
- fixes bugs bz#1294035 bz#1377062 bz#1377387 bz#1378030 bz#1378300 
  bz#1378484 bz#1378528 bz#1378867

* Tue Sep 20 2016 Milind Changire <mchangir@redhat.com> - 3.8.4-1
- rebase to upstream glusterfs at v3.8.4
- fixes bugs bz#1256524 bz#1257182 bz#1294035 bz#1294754 bz#1306120 
  bz#1340756 bz#1344675 bz#1348949 bz#1348954 bz#1348962 bz#1351589 bz#1353427 
  bz#1356058 bz#1359180 bz#1359588 bz#1359605 bz#1359607 bz#1360807 bz#1360978 
  bz#1361066 bz#1361068 bz#1361078 bz#1361082 bz#1361084 bz#1361086 bz#1361118 
  bz#1361170 bz#1361184 bz#1363729 bz#1367382 bz#1369384 bz#1373976

